@@ -33,12 +33,10 @@ static GtkWindowClass *parent_class = NULL;
 extern GtkWidget *main_win;
 
 
-static gboolean
-on_dialog_keypressed (GtkWidget *dialog,
-                      GdkEventKey *event,
-                      gpointer user_data)
+static gboolean on_dialog_keypressed (GtkWidget *dialog, GdkEventKey *event, gpointer user_data)
 {
-    if (event->keyval == GDK_Escape) {
+    if (event->keyval == GDK_Escape)
+    {
         gtk_widget_hide (dialog);
         return TRUE;
     }
@@ -47,11 +45,8 @@ on_dialog_keypressed (GtkWidget *dialog,
 }
 
 
-static void
-on_dialog_show (GtkWidget *w,
-                GnomeCmdDialog *dialog)
+static void on_dialog_show (GtkWidget *w, GnomeCmdDialog *dialog)
 {
-
 }
 
 
@@ -59,8 +54,7 @@ on_dialog_show (GtkWidget *w,
  * Gtk class implementation
  *******************************/
 
-static void
-destroy (GtkObject *object)
+static void destroy (GtkObject *object)
 {
     GnomeCmdDialog *dialog = GNOME_CMD_DIALOG (object);
 
@@ -71,22 +65,17 @@ destroy (GtkObject *object)
 }
 
 
-static void
-map (GtkWidget *widget)
+static void map (GtkWidget *widget)
 {
     if (GTK_WIDGET_CLASS (parent_class)->map != NULL)
         GTK_WIDGET_CLASS (parent_class)->map (widget);
 }
 
 
-static void
-class_init (GnomeCmdDialogClass *klass)
+static void class_init (GnomeCmdDialogClass *klass)
 {
-    GtkObjectClass *object_class;
-    GtkWidgetClass *widget_class;
-
-    object_class = GTK_OBJECT_CLASS (klass);
-    widget_class = GTK_WIDGET_CLASS (klass);
+    GtkObjectClass *object_class = GTK_OBJECT_CLASS (klass);
+    GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
     parent_class = gtk_type_class (gtk_window_get_type ());
     object_class->destroy = destroy;
@@ -94,8 +83,7 @@ class_init (GnomeCmdDialogClass *klass)
 }
 
 
-static void
-init (GnomeCmdDialog *dialog)
+static void init (GnomeCmdDialog *dialog)
 {
     GtkWidget *vbox;
 
@@ -105,11 +93,8 @@ init (GnomeCmdDialog *dialog)
     gtk_window_set_policy (GTK_WINDOW (dialog), FALSE, FALSE, TRUE);
     gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER);
     gtk_window_set_title (GTK_WINDOW (dialog), " ");
-    gnome_cmd_dialog_set_transient_for (
-        GNOME_CMD_DIALOG (dialog),
-        GTK_WINDOW (main_win_widget));
-    gtk_window_set_type_hint (
-        GTK_WINDOW (dialog), GDK_WINDOW_TYPE_HINT_DIALOG);
+    gnome_cmd_dialog_set_transient_for (GNOME_CMD_DIALOG (dialog), GTK_WINDOW (main_win_widget));
+    gtk_window_set_type_hint (GTK_WINDOW (dialog), GDK_WINDOW_TYPE_HINT_DIALOG);
 
     vbox = create_vbox (GTK_WIDGET (dialog), FALSE, 0);
     gtk_container_set_border_width (GTK_CONTAINER (vbox), 12);
@@ -123,10 +108,8 @@ init (GnomeCmdDialog *dialog)
     gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog->priv->buttonbox), GTK_BUTTONBOX_END);
     gtk_box_pack_start (GTK_BOX (vbox), dialog->priv->buttonbox, FALSE, TRUE, 0);
 
-    gtk_signal_connect (GTK_OBJECT (dialog), "key-press-event",
-                        (GtkSignalFunc)on_dialog_keypressed, NULL);
-    gtk_signal_connect (GTK_OBJECT (dialog), "show",
-                        (GtkSignalFunc)on_dialog_show, dialog);
+    gtk_signal_connect (GTK_OBJECT (dialog), "key-press-event", (GtkSignalFunc)on_dialog_keypressed, NULL);
+    gtk_signal_connect (GTK_OBJECT (dialog), "show", (GtkSignalFunc)on_dialog_show, dialog);
 }
 
 
@@ -134,8 +117,7 @@ init (GnomeCmdDialog *dialog)
  * Public functions
  ***********************************/
 
-GtkType
-gnome_cmd_dialog_get_type         (void)
+GtkType gnome_cmd_dialog_get_type (void)
 {
     static GtkType dlg_type = 0;
 
@@ -159,8 +141,7 @@ gnome_cmd_dialog_get_type         (void)
 }
 
 
-GtkWidget*
-gnome_cmd_dialog_new (const gchar *title)
+GtkWidget *gnome_cmd_dialog_new (const gchar *title)
 {
     GnomeCmdDialog *dialog = gtk_type_new (gnome_cmd_dialog_get_type ());
 
@@ -171,8 +152,7 @@ gnome_cmd_dialog_new (const gchar *title)
 }
 
 
-void
-gnome_cmd_dialog_setup (GnomeCmdDialog *dialog, const gchar *title)
+void gnome_cmd_dialog_setup (GnomeCmdDialog *dialog, const gchar *title)
 {
     g_return_if_fail (GNOME_CMD_IS_DIALOG (dialog));
     g_return_if_fail (title != NULL);
@@ -182,18 +162,11 @@ gnome_cmd_dialog_setup (GnomeCmdDialog *dialog, const gchar *title)
 }
 
 
-GtkWidget *
-gnome_cmd_dialog_add_button (GnomeCmdDialog *dialog,
-                             const gchar *stock_id,
-                             GtkSignalFunc on_click,
-                             gpointer data)
+GtkWidget *gnome_cmd_dialog_add_button (GnomeCmdDialog *dialog, const gchar *stock_id, GtkSignalFunc on_click, gpointer data)
 {
-    GtkWidget *btn;
-
     g_return_val_if_fail (GNOME_CMD_IS_DIALOG (dialog), NULL);
 
-    btn = create_stock_button_with_data (
-        GTK_WIDGET (dialog), (gpointer)stock_id, on_click, data);
+    GtkWidget *btn = create_stock_button_with_data (GTK_WIDGET (dialog), (gpointer) stock_id, on_click, data);
 
     gtk_box_pack_start (GTK_BOX (dialog->priv->buttonbox), btn, FALSE, TRUE, 0);
     g_object_set (G_OBJECT (btn), "can-default", TRUE, NULL);
@@ -206,9 +179,7 @@ gnome_cmd_dialog_add_button (GnomeCmdDialog *dialog,
 }
 
 
-void
-gnome_cmd_dialog_add_category (GnomeCmdDialog *dialog,
-                               GtkWidget *category)
+void gnome_cmd_dialog_add_category (GnomeCmdDialog *dialog, GtkWidget *category)
 {
     g_return_if_fail (GNOME_CMD_IS_DIALOG (dialog));
     g_return_if_fail (GTK_IS_WIDGET (category));
@@ -217,9 +188,7 @@ gnome_cmd_dialog_add_category (GnomeCmdDialog *dialog,
 }
 
 
-void
-gnome_cmd_dialog_add_expanding_category (GnomeCmdDialog *dialog,
-                                         GtkWidget *category)
+void gnome_cmd_dialog_add_expanding_category (GnomeCmdDialog *dialog, GtkWidget *category)
 {
     g_return_if_fail (GNOME_CMD_IS_DIALOG (dialog));
     g_return_if_fail (GTK_IS_WIDGET (category));
@@ -228,43 +197,29 @@ gnome_cmd_dialog_add_expanding_category (GnomeCmdDialog *dialog,
 }
 
 
-void
-gnome_cmd_dialog_editable_enters (GnomeCmdDialog *dialog,
-                                  GtkEditable *editable)
+void gnome_cmd_dialog_editable_enters (GnomeCmdDialog *dialog, GtkEditable *editable)
 {
-  g_return_if_fail(GNOME_CMD_IS_DIALOG(dialog));
-  g_return_if_fail(GTK_IS_EDITABLE(editable));
+    g_return_if_fail (GNOME_CMD_IS_DIALOG (dialog));
+    g_return_if_fail (GTK_IS_EDITABLE (editable));
 
-  g_signal_connect_swapped(editable, "activate",
-                           G_CALLBACK(gtk_window_activate_default),
-                           dialog);
+    g_signal_connect_swapped(editable, "activate", G_CALLBACK(gtk_window_activate_default), dialog);
 }
 
 
-void
-gnome_cmd_dialog_set_transient_for (GnomeCmdDialog *dialog,
-                                    GtkWindow *win)
+void gnome_cmd_dialog_set_transient_for (GnomeCmdDialog *dialog, GtkWindow *win)
 {
     gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (win));
 }
 
 
-void
-gnome_cmd_dialog_set_modal (GnomeCmdDialog *dialog)
+void gnome_cmd_dialog_set_modal (GnomeCmdDialog *dialog)
 {
     gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
 }
 
 
-void
-gnome_cmd_dialog_set_resizable (GnomeCmdDialog *dialog, gboolean value)
+void gnome_cmd_dialog_set_resizable (GnomeCmdDialog *dialog, gboolean value)
 {
     gtk_window_set_resizable (GTK_WINDOW (dialog), value);
-
-    if (value) {
-        gtk_window_set_policy (GTK_WINDOW (dialog), FALSE, TRUE, FALSE);
-    }
-    else {
-        gtk_window_set_policy (GTK_WINDOW (dialog), FALSE, FALSE, TRUE);
-    }
+    gtk_window_set_policy (GTK_WINDOW (dialog), FALSE, value, !value);
 }
