@@ -14,12 +14,14 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #ifndef __GNOME_CMD_PLUGIN_H__
 #define __GNOME_CMD_PLUGIN_H__
 
+G_BEGIN_DECLS
+
 #define GNOME_CMD_PLUGIN(obj) \
     GTK_CHECK_CAST (obj, gnome_cmd_plugin_get_type (), GnomeCmdPlugin)
 #define GNOME_CMD_PLUGIN_CLASS(klass) \
@@ -66,4 +68,6 @@ gnome_cmd_plugin_update_main_menu_state (GnomeCmdPlugin *plugin, GnomeCmdState *
 void
 gnome_cmd_plugin_configure (GnomeCmdPlugin *plugin);
 
+G_END_DECLS
+
 #endif //__GNOME_CMD_PLUGIN_H__
