@@ -45,7 +45,7 @@ typedef struct
 } RenameEntry;
 
 
-enum {DIR_MENU, NAME_MENU, COUNTER_MENU, DATE_MENU, METATAG_MENU, NUM_MENUS};
+enum {DIR_MENU, FILE_MENU, COUNTER_MENU, DATE_MENU, METATAG_MENU, NUM_MENUS};
 
 
 struct _GnomeCmdAdvrenameDialogPrivate
@@ -79,7 +79,7 @@ guint advrename_dialog_default_res_column_width[ADVRENAME_DIALOG_RES_NUM_COLUMNS
 static void do_test (GnomeCmdAdvrenameDialog *dialog);
 
 
-inline void insert_tag(GnomeCmdAdvrenameDialog *dialog, const gchar *text)
+inline void insert_tag (GnomeCmdAdvrenameDialog *dialog, const gchar *text)
 {
     GtkEditable *editable = (GtkEditable *) dialog->priv->templ_entry;
     gint pos = gtk_editable_get_position(editable);
@@ -93,34 +93,34 @@ inline void insert_tag(GnomeCmdAdvrenameDialog *dialog, const gchar *text)
 
 static void insert_text_tag(gpointer data, guint n, GtkWidget *widget)
 {
-    static gchar *placeholder[] = {"$g",
-                                   "$p",
-                                   "$N",
-                                   "$n",
-                                   "$e",
-                                   "$c",
-                                   "$c(2)",
-                                   "%x",
-                                   "%Y-%m-%d",
-                                   "%y-%m-%d",
-                                   "%y.%m.%d",
-                                   "%y%m%d",
-                                   "%d.%m.%y",
-                                   "%m-%d-%y",
-                                   "%Y",
-                                   "%y",
-                                   "%m",
-                                   "%b",
-                                   "%d",
-                                   "%X",
-                                   "%H.%M.%S",
-                                   "%H-%M-%S",
-                                   "%H%M%S",
-                                   "%H",
-                                   "%M",
-                                   "%S"};
+    static const gchar *placeholder[] = {"$g",
+                                         "$p",
+                                         "$N",
+                                         "$n",
+                                         "$e",
+                                         "$c",
+                                         "$c(2)",
+                                         "%x",
+                                         "%Y-%m-%d",
+                                         "%y-%m-%d",
+                                         "%y.%m.%d",
+                                         "%y%m%d",
+                                         "%d.%m.%y",
+                                         "%m-%d-%y",
+                                         "%Y",
+                                         "%y",
+                                         "%m",
+                                         "%b",
+                                         "%d",
+                                         "%X",
+                                         "%H.%M.%S",
+                                         "%H-%M-%S",
+                                         "%H%M%S",
+                                         "%H",
+                                         "%M",
+                                         "%S"};
 
-    g_return_if_fail(n < ARRAY_ELEMENTS(placeholder));
+    g_return_if_fail (n < G_N_ELEMENTS(placeholder));
 
     insert_tag((GnomeCmdAdvrenameDialog *) data, placeholder[n]);
 }
@@ -180,15 +180,25 @@ static GtkWidget *create_placeholder_menu(GnomeCmdAdvrenameDialog *dialog, int m
                                            {_("/Time/SS"), NULL, (GtkItemFactoryCallback) insert_text_tag, 25}};
 
     static GnomeCmdTag metatags[] = {
+                                     TAG_FILE_NAME, TAG_FILE_PATH,
+                                     TAG_FILE_LINK,
+                                     TAG_FILE_SIZE,
+                                     TAG_FILE_MODIFIED, TAG_FILE_ACCESSED,
+                                     TAG_FILE_PERMISSIONS,
+                                     TAG_FILE_FORMAT,
+                                     TAG_FILE_PUBLISHER, TAG_FILE_DESCRIPTION, TAG_FILE_KEYWORDS, TAG_FILE_RANK,
+
                                      TAG_AUDIO_ALBUMARTIST, TAG_AUDIO_ALBUMGAIN, TAG_AUDIO_ALBUMPEAKGAIN,
                                      TAG_AUDIO_ALBUMTRACKCOUNT, TAG_AUDIO_ALBUM, TAG_AUDIO_ARTIST, TAG_AUDIO_BITRATE,
                                      TAG_AUDIO_CHANNELS, TAG_AUDIO_CODECVERSION, TAG_AUDIO_CODEC, TAG_AUDIO_COMMENT,
-                                     TAG_AUDIO_COVERALBUMTHUMBNAILPATH, TAG_AUDIO_DISCNO, TAG_AUDIO_DURATION,
-                                     TAG_AUDIO_GENRE, TAG_AUDIO_ISNEW, TAG_AUDIO_LASTPLAY, TAG_AUDIO_LYRICS,
+                                     TAG_AUDIO_COVERALBUMTHUMBNAILPATH, TAG_AUDIO_DISCNO,
+                                     TAG_AUDIO_DURATION, TAG_AUDIO_DURATIONMMSS,
+                                     TAG_AUDIO_GENRE, TAG_AUDIO_ISNEW, TAG_AUDIO_ISRC, TAG_AUDIO_LASTPLAY, TAG_AUDIO_LYRICS,
                                      TAG_AUDIO_MBALBUMARTISTID, TAG_AUDIO_MBALBUMID, TAG_AUDIO_MBARTISTID,
                                      TAG_AUDIO_MBTRACKID, TAG_AUDIO_PERFORMER, TAG_AUDIO_PLAYCOUNT,
                                      TAG_AUDIO_RELEASEDATE, TAG_AUDIO_SAMPLERATE, TAG_AUDIO_TITLE, TAG_AUDIO_TRACKGAIN,
-                                     TAG_AUDIO_TRACKNO, TAG_AUDIO_TRACKPEAKGAIN,
+                                     TAG_AUDIO_TRACKNO, TAG_AUDIO_TRACKPEAKGAIN, TAG_AUDIO_YEAR,
+                                     TAG_AUDIO_MPEG_CHANNELMODE, TAG_AUDIO_MPEG_LAYER, TAG_AUDIO_MPEG_VERSION,
 
                                      TAG_DOC_AUTHOR, TAG_DOC_CREATOR, TAG_DOC_TITLE,
                                      TAG_DOC_SUBJECT, TAG_DOC_DESCRIPTION,
@@ -212,12 +222,7 @@ static GtkWidget *create_placeholder_menu(GnomeCmdAdvrenameDialog *dialog, int m
                                      TAG_DOC_TABLECOUNT, TAG_DOC_TEMPLATE,
                                      TAG_DOC_CASESENSITIVE, TAG_DOC_LINKSDIRTY,
 
-                                     // TAG_FILE_ACCESSED, TAG_FILE_CONTENT, TAG_FILE_DESCRIPTION, TAG_FILE_FORMAT,
-                                     // TAG_FILE_ICONPATH, TAG_FILE_KEYWORDS, TAG_FILE_LARGETHUMBNAILPATH, TAG_FILE_LINK,
-                                     // TAG_FILE_MODIFIED, TAG_FILE_NAME, TAG_FILE_PATH, TAG_FILE_PERMISSIONS,
-                                     // TAG_FILE_PUBLISHER, TAG_FILE_RANK, TAG_FILE_SIZE, TAG_FILE_SMALLTHUMBNAILPATH,
-
-                                     TAG_IMAGE_ALBUM, TAG_IMAGE_CAMERAMAKE, TAG_IMAGE_CAMERAMODEL,
+                                     TAG_IMAGE_ALBUM, TAG_IMAGE_MAKE, TAG_IMAGE_MODEL,
                                      TAG_IMAGE_COMMENTS, TAG_IMAGE_COPYRIGHT, TAG_IMAGE_CREATOR,
                                      TAG_IMAGE_DATE, TAG_IMAGE_DESCRIPTION, TAG_IMAGE_EXPOSUREPROGRAM,
                                      TAG_IMAGE_EXPOSURETIME, TAG_IMAGE_FLASH, TAG_IMAGE_FNUMBER,
@@ -228,29 +233,26 @@ static GtkWidget *create_placeholder_menu(GnomeCmdAdvrenameDialog *dialog, int m
 
                                      TAG_NONE,
 
-                                     TAG_ID3_ALBUM, TAG_ID3_BAND, TAG_ID3_BITRATE,
-                                     TAG_ID3_CHANNELS, TAG_ID3_CONTENTTYPE,
-                                     TAG_ID3_DURATION, TAG_ID3_DURATIONMMSS,
-                                     TAG_ID3_GENRE, TAG_ID3_LEADARTIST, TAG_ID3_SAMPLERATE,
-                                     TAG_ID3_TITLE, TAG_ID3_TRACKNUM,
-
+                                     TAG_ID3_BAND,
+                                     TAG_ID3_CONTENTTYPE,
                                      TAG_ID3_ALBUMSORTORDER, TAG_ID3_AUDIOCRYPTO,
                                      TAG_ID3_AUDIOSEEKPOINT,
                                      TAG_ID3_BPM, TAG_ID3_BUFFERSIZE, TAG_ID3_CDID,
-                                     TAG_ID3_CHANNELMODE, TAG_ID3_COMMENT,
                                      TAG_ID3_COMMERCIAL, TAG_ID3_COMPOSER, TAG_ID3_CONDUCTOR,
-                                     TAG_ID3_CONTENTGROUP, TAG_ID3_COPYRIGHT,
+                                     TAG_ID3_CONTENTGROUP, TAG_ID3_CONTENTTYPE,
+                                     TAG_ID3_COPYRIGHT,
                                      TAG_ID3_CRYPTOREG, TAG_ID3_DATE,
                                      TAG_ID3_EMPHASIS, TAG_ID3_ENCODEDBY,
                                      TAG_ID3_ENCODERSETTINGS, TAG_ID3_ENCODINGTIME, TAG_ID3_EQUALIZATION,
                                      TAG_ID3_EQUALIZATION2, TAG_ID3_EVENTTIMING, TAG_ID3_FILEOWNER,
                                      TAG_ID3_FILETYPE, TAG_ID3_FRAMES, TAG_ID3_GENERALOBJECT,
                                      TAG_ID3_GROUPINGREG, TAG_ID3_INITIALKEY,
-                                     TAG_ID3_INVOLVEDPEOPLE, TAG_ID3_INVOLVEDPEOPLE2, TAG_ID3_ISRC,
+                                     TAG_ID3_INVOLVEDPEOPLE, TAG_ID3_INVOLVEDPEOPLE2,
                                      TAG_ID3_LANGUAGE, TAG_ID3_LINKEDINFO,
                                      TAG_ID3_LYRICIST, TAG_ID3_MEDIATYPE, TAG_ID3_MIXARTIST,
-                                     TAG_ID3_MOOD, TAG_ID3_MPEGLAYER, TAG_ID3_MPEGLOOKUP,
-                                     TAG_ID3_MPEGVERSION, TAG_ID3_MUSICIANCREDITLIST,
+                                     TAG_ID3_MOOD,
+                                     TAG_ID3_MPEGLOOKUP,
+                                     TAG_ID3_MUSICIANCREDITLIST,
                                      TAG_ID3_NETRADIOOWNER, TAG_ID3_NETRADIOSTATION,
                                      TAG_ID3_ORIGALBUM, TAG_ID3_ORIGARTIST, TAG_ID3_ORIGFILENAME,
                                      TAG_ID3_ORIGLYRICIST, TAG_ID3_ORIGRELEASETIME, TAG_ID3_ORIGYEAR,
@@ -267,7 +269,7 @@ static GtkWidget *create_placeholder_menu(GnomeCmdAdvrenameDialog *dialog, int m
                                      TAG_ID3_VOLUMEADJ, TAG_ID3_VOLUMEADJ2, TAG_ID3_WWWARTIST,
                                      TAG_ID3_WWWAUDIOFILE, TAG_ID3_WWWAUDIOSOURCE, TAG_ID3_WWWCOMMERCIALINFO,
                                      TAG_ID3_WWWCOPYRIGHT, TAG_ID3_WWWPAYMENT, TAG_ID3_WWWPUBLISHER,
-                                     TAG_ID3_WWWRADIOPAGE, TAG_ID3_WWWUSER, TAG_ID3_YEAR,
+                                     TAG_ID3_WWWRADIOPAGE, TAG_ID3_WWWUSER,
 
                                      TAG_EXIF_COPYRIGHT, TAG_EXIF_DATETIME,
                                      TAG_EXIF_EXPOSUREBIASVALUE, TAG_EXIF_EXPOSUREMODE, TAG_EXIF_EXPOSUREPROGRAM,
@@ -348,7 +350,13 @@ static GtkWidget *create_placeholder_menu(GnomeCmdAdvrenameDialog *dialog, int m
                                      TAG_IPTC_RELEASEDATE, TAG_IPTC_RELEASETIME, TAG_IPTC_SERVICEID,
                                      TAG_IPTC_SIZEMODE, TAG_IPTC_SOURCE, TAG_IPTC_SUBFILE, TAG_IPTC_SUBJECTREFERENCE,
                                      TAG_IPTC_SUPPLCATEGORY, TAG_IPTC_TIMECREATED, TAG_IPTC_TIMESENT, TAG_IPTC_UNO,
-                                     TAG_IPTC_URGENCY, TAG_IPTC_WRITEREDITOR
+                                     TAG_IPTC_URGENCY, TAG_IPTC_WRITEREDITOR,
+
+                                     TAG_VORBIS_CONTACT, TAG_VORBIS_DESCRIPTION,
+                                     TAG_VORBIS_LICENSE, TAG_VORBIS_LOCATION,
+                                     TAG_VORBIS_MAXBITRATE, TAG_VORBIS_MINBITRATE,
+                                     TAG_VORBIS_NOMINALBITRATE, TAG_VORBIS_ORGANIZATION,
+                                     TAG_VORBIS_VENDOR, TAG_VORBIS_VERSION
                                     };
 
     GtkItemFactoryEntry *items[] = {dir_items,
@@ -356,15 +364,15 @@ static GtkWidget *create_placeholder_menu(GnomeCmdAdvrenameDialog *dialog, int m
                                     counter_items,
                                     date_items};
 
-    static guint items_size[] = {ARRAY_ELEMENTS(dir_items),
-                                 ARRAY_ELEMENTS(name_items),
-                                 ARRAY_ELEMENTS(counter_items),
-                                 ARRAY_ELEMENTS(date_items)};
+    static guint items_size[] = {G_N_ELEMENTS(dir_items),
+                                 G_N_ELEMENTS(name_items),
+                                 G_N_ELEMENTS(counter_items),
+                                 G_N_ELEMENTS(date_items)};
 
     switch (menu_type)
     {
         case DIR_MENU:
-        case NAME_MENU:
+        case FILE_MENU:
         case COUNTER_MENU:
         case DATE_MENU:
             {
@@ -377,32 +385,34 @@ static GtkWidget *create_placeholder_menu(GnomeCmdAdvrenameDialog *dialog, int m
 
         case METATAG_MENU:
             {
-                GtkItemFactoryEntry *items = g_try_new0(GtkItemFactoryEntry, ARRAY_ELEMENTS(metatags));
+                GtkItemFactoryEntry *items = g_try_new0(GtkItemFactoryEntry, G_N_ELEMENTS(metatags));
 
                 g_return_val_if_fail (items != NULL, NULL);
 
-                for (gint i=0; i<ARRAY_ELEMENTS(metatags); ++i)
+                for (guint i=0; i<G_N_ELEMENTS(metatags); ++i)
                 {
+                    GnomeCmdTag tag = metatags[i];
+                    const gchar *class_name = gcmd_tags_get_class_name(tag);
                     GtkItemFactoryEntry *p = items+i;
 
-                    if (metatags[i]==TAG_NONE)
+                    if (!class_name || *class_name==0)
                     {
                         p->path = g_strdup("/");
                         p->item_type = "<Separator>";
                     }
                     else
                     {
-                        p->path = g_strdup_printf ("/%s/%s", gcmd_tags_get_class_name(metatags[i]), gcmd_tags_get_title(metatags[i]));
+                        p->path = g_strdup_printf ("/%s/%s", gcmd_tags_get_class_name(tag), gcmd_tags_get_title(tag));
                         p->callback = (GtkItemFactoryCallback) insert_num_tag;
-                        p->callback_action = metatags[i];
+                        p->callback_action = tag;
                     }
                 }
 
                 GtkItemFactory *ifac = gtk_item_factory_new (GTK_TYPE_MENU, "<main>", NULL);
 
-                gtk_item_factory_create_items (ifac, ARRAY_ELEMENTS(metatags), items, dialog);
+                gtk_item_factory_create_items (ifac, G_N_ELEMENTS(metatags), items, dialog);
 
-                for (gint i=0; i<ARRAY_ELEMENTS(metatags); ++i)
+                for (guint i=0; i<G_N_ELEMENTS(metatags); ++i)
                     g_free(items[i].path);
 
                 g_free (items);
@@ -416,7 +426,7 @@ static GtkWidget *create_placeholder_menu(GnomeCmdAdvrenameDialog *dialog, int m
 }
 
 
-static GtkWidget *create_button_with_menu(GnomeCmdAdvrenameDialog *dialog, gchar *label_text, int menu_type)
+static GtkWidget *create_button_with_menu (GnomeCmdAdvrenameDialog *dialog, gchar *label_text, int menu_type)
 {
     GtkWidget *arrow = gtk_arrow_new (GTK_ARROW_DOWN, GTK_SHADOW_NONE);
     GtkWidget *label = gtk_label_new (label_text);
@@ -439,8 +449,7 @@ static GtkWidget *create_button_with_menu(GnomeCmdAdvrenameDialog *dialog, gchar
 }
 
 
-static void
-free_data (GnomeCmdAdvrenameDialog *dialog)
+inline void free_data (GnomeCmdAdvrenameDialog *dialog)
 {
     gnome_cmd_file_list_free (dialog->priv->files);
 
@@ -487,7 +496,7 @@ inline gint get_row_from_rename_entry (GnomeCmdAdvrenameDialog *dialog, RenameEn
 inline void add_rename_entry (GnomeCmdAdvrenameDialog *dialog, GnomeCmdFile *finfo)
 {
     gint row;
-    gchar *text[3],
+    gchar *text[4],
           *fname = get_utf8 (finfo->info->name);
     RenameEntry *entry = rename_entry_new ();
 
@@ -496,6 +505,7 @@ inline void add_rename_entry (GnomeCmdAdvrenameDialog *dialog, GnomeCmdFile *fin
     text[0] = fname;
     text[1] = NULL;
     text[2] = NULL;
+    text[3] = NULL;
 
     row = gtk_clist_append (GTK_CLIST (dialog->priv->res_list), text);
     gtk_clist_set_row_data (GTK_CLIST (dialog->priv->res_list), row, entry);
@@ -535,7 +545,7 @@ inline void update_remove_all_button (GnomeCmdAdvrenameDialog *dialog)
 inline void add_pattern_entry (GnomeCmdAdvrenameDialog *dialog, PatternEntry *entry)
 {
     gint row;
-    gchar *text[3];
+    gchar *text[4];
 
     if (!entry) return;
 
@@ -548,10 +558,7 @@ inline void add_pattern_entry (GnomeCmdAdvrenameDialog *dialog, PatternEntry *en
 }
 
 
-inline gchar*
-update_entry (PatternEntry *entry,
-              GnomeCmdStringDialog *string_dialog,
-              const gchar **values)
+inline gchar *update_entry (PatternEntry *entry, GnomeCmdStringDialog *string_dialog, const gchar **values)
 {
     if (!values[0])
         return g_strdup (_("Invalid source pattern"));
@@ -568,15 +575,12 @@ update_entry (PatternEntry *entry,
 }
 
 
-static gboolean
-on_add_rule_dialog_ok (GnomeCmdStringDialog *string_dialog,
-                       const gchar **values,
-                       GnomeCmdAdvrenameDialog *dialog)
+static gboolean on_add_rule_dialog_ok (GnomeCmdStringDialog *string_dialog, const gchar **values, GnomeCmdAdvrenameDialog *dialog)
 {
-    gchar *error_desc;
     PatternEntry *entry = g_new0 (PatternEntry, 1);
 
-    error_desc = update_entry (entry, string_dialog, values);
+    gchar *error_desc = update_entry (entry, string_dialog, values);
+
     if (error_desc != NULL)
     {
         gnome_cmd_string_dialog_set_error_desc (string_dialog, error_desc);
@@ -592,25 +596,23 @@ on_add_rule_dialog_ok (GnomeCmdStringDialog *string_dialog,
 }
 
 
-static gboolean
-on_edit_rule_dialog_ok (GnomeCmdStringDialog *string_dialog,
-                        const gchar **values,
-                        GnomeCmdAdvrenameDialog *dialog)
+static gboolean on_edit_rule_dialog_ok (GnomeCmdStringDialog *string_dialog, const gchar **values, GnomeCmdAdvrenameDialog *dialog)
 {
     GtkWidget *pat_list = dialog->priv->pat_list;
     gint row = GTK_CLIST (pat_list)->focus_row;
     PatternEntry *entry = (PatternEntry *) g_list_nth_data (dialog->priv->defaults->patterns, row);
-    gchar *text[3], *error_desc;
 
     g_return_val_if_fail (entry != NULL, TRUE);
 
-    error_desc = update_entry (entry, string_dialog, values);
+    gchar *error_desc = update_entry (entry, string_dialog, values);
     if (error_desc != NULL)
     {
         gnome_cmd_string_dialog_set_error_desc (string_dialog, error_desc);
         return FALSE;
     }
 
+    gchar *text[4];
+
     format_entry (entry, text);
     //gtk_clist_set_foreground(GTK_CLIST (pat_list), row, entry->malformed_pattern ? &red : &black);
     gtk_clist_set_text (GTK_CLIST (pat_list), row, 0, text[0]);
@@ -624,25 +626,18 @@ on_edit_rule_dialog_ok (GnomeCmdStringDialog *string_dialog,
 }
 
 
-static GtkWidget*
-create_rule_dialog (GnomeCmdAdvrenameDialog *parent_dialog,
-                    const gchar *title,
-                    GnomeCmdStringDialogCallback on_ok_func,
-                    PatternEntry *entry)
+static GtkWidget *create_rule_dialog (GnomeCmdAdvrenameDialog *parent_dialog, const gchar *title, GnomeCmdStringDialogCallback on_ok_func, PatternEntry *entry)
 {
-    const gchar *labels[] = {_("Replace this:"), _("With this")};
-    GtkWidget *dialog;
-    GtkWidget *case_check;
+    // Translators: this is a part of dialog for replacing text 'Replace this:' -> 'With this:'
+    const gchar *labels[] = {_("Replace this:"), _("With this:")};
 
-    dialog = gnome_cmd_string_dialog_new (title, labels, 2, on_ok_func, parent_dialog);
+    GtkWidget *dialog = gnome_cmd_string_dialog_new (title, labels, 2, on_ok_func, parent_dialog);
     gtk_widget_ref (dialog);
-    gtk_object_set_data_full (GTK_OBJECT (parent_dialog),
-                              "rule-dialog", dialog,
-                              (GtkDestroyNotify)gtk_widget_unref);
+    gtk_object_set_data_full (GTK_OBJECT (parent_dialog), "rule-dialog", dialog, (GtkDestroyNotify) gtk_widget_unref);
     gnome_cmd_string_dialog_set_value (GNOME_CMD_STRING_DIALOG (dialog), 0, entry?entry->from:"");
     gnome_cmd_string_dialog_set_value (GNOME_CMD_STRING_DIALOG (dialog), 1, entry?entry->to:"");
 
-    case_check = create_check (dialog, _("Case sensitive matching"), "case_check");
+    GtkWidget *case_check = create_check (dialog, _("Case sensitive matching"), "case_check");
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (case_check), entry?entry->case_sens:FALSE);
     gnome_cmd_dialog_add_category (GNOME_CMD_DIALOG (dialog), case_check);
 
@@ -652,8 +647,7 @@ create_rule_dialog (GnomeCmdAdvrenameDialog *parent_dialog,
 }
 
 
-static gchar *
-apply_one_pattern (gchar *in, PatternEntry *entry, int eflags)
+static gchar *apply_one_pattern (gchar *in, PatternEntry *entry, int eflags)
 {
     regex_t re_exp;
     regmatch_t re_match_info;
@@ -661,17 +655,17 @@ apply_one_pattern (gchar *in, PatternEntry *entry, int eflags)
 
     if (!in || !entry) return NULL;
 
-    if (regcomp (&re_exp, entry->from, (entry->case_sens ? REG_EXTENDED : REG_EXTENDED|REG_ICASE) != 0))
+    if (regcomp (&re_exp, entry->from, (entry->case_sens ? REG_EXTENDED : REG_EXTENDED|REG_ICASE)) != 0)
         entry->malformed_pattern = TRUE;
     else
     {
         if (regexec (&re_exp, in, 1, &re_match_info, eflags) == 0)
         {
             if (strcmp (entry->from, "$") == 0)
-                out = g_strconcat(in, entry->to, NULL);
+                out = g_strconcat (in, entry->to, NULL);
             else
                 if (strcmp (entry->from, "^") == 0)
-                    out = g_strconcat(entry->to, in, NULL);
+                    out = g_strconcat (entry->to, in, NULL);
                 else
                 {
                     gint match_size = re_match_info.rm_eo - re_match_info.rm_so;
@@ -701,8 +695,7 @@ apply_one_pattern (gchar *in, PatternEntry *entry, int eflags)
 }
 
 
-static gchar *
-create_new_name (const gchar *name, GList *patterns)
+inline gchar *create_new_name (const gchar *name, GList *patterns)
 {
     gchar *tmp = NULL;
     gchar *new_name = g_strdup (name);
@@ -722,14 +715,11 @@ create_new_name (const gchar *name, GList *patterns)
 }
 
 
-static void update_new_names (GnomeCmdAdvrenameDialog *dialog)
+inline void update_new_names (GnomeCmdAdvrenameDialog *dialog)
 {
     const gchar *templ_string = gtk_entry_get_text (GTK_ENTRY (dialog->priv->templ_entry));
 
-    gnome_cmd_advrename_reset_counter (
-        dialog->priv->defaults->counter_start,
-        dialog->priv->defaults->counter_precision,
-        dialog->priv->defaults->counter_increment);
+    gnome_cmd_advrename_reset_counter (dialog->priv->defaults->counter_start, dialog->priv->defaults->counter_precision, dialog->priv->defaults->counter_increment);
     gnome_cmd_advrename_parse_fname (templ_string);
 
     for (GList *tmp = dialog->priv->entries; tmp; tmp = tmp->next)
@@ -759,8 +749,7 @@ static void redisplay_new_names (GnomeCmdAdvrenameDialog *dialog)
 }
 
 
-static void
-change_names (GnomeCmdAdvrenameDialog *dialog)
+inline void change_names (GnomeCmdAdvrenameDialog *dialog)
 {
     for (GList *tmp = dialog->priv->entries; tmp; tmp = tmp->next)
     {
@@ -774,13 +763,13 @@ change_names (GnomeCmdAdvrenameDialog *dialog)
 
 static void on_rule_add (GtkButton *button, GnomeCmdAdvrenameDialog *dialog)
 {
-    create_rule_dialog (dialog, _("New Rule"), (GnomeCmdStringDialogCallback)on_add_rule_dialog_ok, NULL);
+    create_rule_dialog (dialog, _("New Rule"), (GnomeCmdStringDialogCallback) on_add_rule_dialog_ok, NULL);
 }
 
 
 static void on_rule_edit (GtkButton *button, GnomeCmdAdvrenameDialog *dialog)
 {
-    create_rule_dialog (dialog, _("Edit Rule"), (GnomeCmdStringDialogCallback)on_edit_rule_dialog_ok, dialog->priv->sel_entry);
+    create_rule_dialog (dialog, _("Edit Rule"), (GnomeCmdStringDialogCallback) on_edit_rule_dialog_ok, dialog->priv->sel_entry);
 }
 
 
@@ -809,18 +798,13 @@ static void on_rule_remove_all (GtkButton *button, GnomeCmdAdvrenameDialog *dial
 }
 
 
-static void
-on_pat_list_scroll_vertical (GtkCList *clist,
-                             GtkScrollType scroll_type,
-                             gfloat position,
-                             GnomeCmdAdvrenameDialog *dialog)
+static void on_pat_list_scroll_vertical (GtkCList *clist, GtkScrollType scroll_type, gfloat position, GnomeCmdAdvrenameDialog *dialog)
 {
     gtk_clist_select_row (clist, clist->focus_row, 0);
 }
 
 
-static void on_rule_selected (GtkCList *list, gint row, gint column,
-                              GdkEventButton *event, GnomeCmdAdvrenameDialog *dialog)
+static void on_rule_selected (GtkCList *list, gint row, gint column, GdkEventButton *event, GnomeCmdAdvrenameDialog *dialog)
 {
     gtk_widget_set_sensitive (dialog->priv->remove_btn, TRUE);
     gtk_widget_set_sensitive (dialog->priv->edit_btn, TRUE);
@@ -829,8 +813,7 @@ static void on_rule_selected (GtkCList *list, gint row, gint column,
 }
 
 
-static void on_rule_unselected (GtkCList *list, gint row, gint column,
-                                GdkEventButton *event, GnomeCmdAdvrenameDialog *dialog)
+static void on_rule_unselected (GtkCList *list, gint row, gint column, GdkEventButton *event, GnomeCmdAdvrenameDialog *dialog)
 {
     gtk_widget_set_sensitive (dialog->priv->remove_btn, FALSE);
     gtk_widget_set_sensitive (dialog->priv->edit_btn, FALSE);
@@ -866,9 +849,7 @@ static void on_rule_move_down (GtkButton *button, GnomeCmdAdvrenameDialog *dialo
 }
 
 
-static void
-on_rule_moved (GtkCList *clist, gint arg1, gint arg2,
-               GnomeCmdAdvrenameDialog *dialog)
+static void on_rule_moved (GtkCList *clist, gint arg1, gint arg2, GnomeCmdAdvrenameDialog *dialog)
 {
     GList *pats = dialog->priv->defaults->patterns;
 
@@ -887,8 +868,7 @@ on_rule_moved (GtkCList *clist, gint arg1, gint arg2,
 }
 
 
-static void
-save_settings (GnomeCmdAdvrenameDialog *dialog)
+inline void save_settings (GnomeCmdAdvrenameDialog *dialog)
 {
     const gchar *template_string = gtk_entry_get_text (GTK_ENTRY (dialog->priv->templ_entry));
 
@@ -931,8 +911,7 @@ static void on_help (GtkButton *button, GnomeCmdAdvrenameDialog *dialog)
 }
 
 
-static gboolean
-on_dialog_keypress (GnomeCmdAdvrenameDialog *dialog, GdkEventKey *event)
+static gboolean on_dialog_keypress (GnomeCmdAdvrenameDialog *dialog, GdkEventKey *event)
 {
     if (event->keyval == GDK_Escape)
     {
@@ -951,18 +930,14 @@ static void do_test (GnomeCmdAdvrenameDialog *dialog)
 }
 
 
-static void
-on_templ_entry_changed (GtkEntry *entry,
-                        GnomeCmdAdvrenameDialog *dialog)
+static void on_templ_entry_changed (GtkEntry *entry, GnomeCmdAdvrenameDialog *dialog)
 {
     if (dialog->priv->defaults->auto_update)
         do_test (dialog);
 }
 
 
-static gboolean
-on_templ_entry_keypress (GtkEntry *entry, GdkEventKey *event,
-                         GnomeCmdAdvrenameDialog *dialog)
+static gboolean on_templ_entry_keypress (GtkEntry *entry, GdkEventKey *event, GnomeCmdAdvrenameDialog *dialog)
 {
     if (event->keyval == GDK_Return)
     {
@@ -974,10 +949,7 @@ on_templ_entry_keypress (GtkEntry *entry, GdkEventKey *event,
 }
 
 
-static gboolean
-on_template_options_ok (GnomeCmdStringDialog *string_dialog,
-                        const gchar **values,
-                        GnomeCmdAdvrenameDialog *dialog)
+static gboolean on_template_options_ok (GnomeCmdStringDialog *string_dialog, const gchar **values, GnomeCmdAdvrenameDialog *dialog)
 {
     guint start, precision, inc;
 
@@ -1002,9 +974,7 @@ on_template_options_ok (GnomeCmdStringDialog *string_dialog,
 }
 
 
-static void
-on_template_options_clicked (GtkButton *button,
-                             GnomeCmdAdvrenameDialog *dialog)
+static void on_template_options_clicked (GtkButton *button, GnomeCmdAdvrenameDialog *dialog)
 {
     const gchar *labels[] = {
         _("Counter start value:"),
@@ -1036,24 +1006,19 @@ on_template_options_clicked (GtkButton *button,
 }
 
 
-static void
-on_res_list_column_resize (GtkCList *clist, gint column, gint width, GnomeCmdAdvrenameDialog *dialog)
+static void on_res_list_column_resize (GtkCList *clist, gint column, gint width, GnomeCmdAdvrenameDialog *dialog)
 {
     advrename_dialog_default_res_column_width[column] = width;
 }
 
 
-static void
-on_pat_list_column_resize (GtkCList *clist, gint column, gint width, GnomeCmdAdvrenameDialog *dialog)
+static void on_pat_list_column_resize (GtkCList *clist, gint column, gint width, GnomeCmdAdvrenameDialog *dialog)
 {
     advrename_dialog_default_pat_column_width[column] = width;
 }
 
 
-static void
-on_dialog_size_allocate (GtkWidget       *widget,
-                         GtkAllocation   *allocation,
-                         GnomeCmdAdvrenameDialog *dialog)
+static void on_dialog_size_allocate (GtkWidget *widget, GtkAllocation *allocation, GnomeCmdAdvrenameDialog *dialog)
 {
     dialog->priv->defaults->width  = allocation->width;
     dialog->priv->defaults->height = allocation->height;
@@ -1064,8 +1029,7 @@ on_dialog_size_allocate (GtkWidget       *widget,
  * Gtk class implementation
  *******************************/
 
-static void
-destroy (GtkObject *object)
+static void destroy (GtkObject *object)
 {
     GnomeCmdAdvrenameDialog *dialog = GNOME_CMD_ADVRENAME_DIALOG (object);
 
@@ -1076,16 +1040,14 @@ destroy (GtkObject *object)
 }
 
 
-static void
-map (GtkWidget *widget)
+static void map (GtkWidget *widget)
 {
     if (GTK_WIDGET_CLASS (parent_class)->map != NULL)
         GTK_WIDGET_CLASS (parent_class)->map (widget);
 }
 
 
-static void
-class_init (GnomeCmdAdvrenameDialogClass *klass)
+static void class_init (GnomeCmdAdvrenameDialogClass *klass)
 {
     GtkObjectClass *object_class = GTK_OBJECT_CLASS (klass);
     GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
@@ -1096,8 +1058,7 @@ class_init (GnomeCmdAdvrenameDialogClass *klass)
 }
 
 
-static void
-init (GnomeCmdAdvrenameDialog *in_dialog)
+static void init (GnomeCmdAdvrenameDialog *in_dialog)
 {
     GtkWidget *vbox;
     GtkWidget *sw;
@@ -1132,6 +1093,7 @@ init (GnomeCmdAdvrenameDialog *in_dialog)
     gnome_cmd_dialog_add_category (GNOME_CMD_DIALOG (dialog), cat);
 
     in_dialog->priv->templ_combo = create_combo (dialog);
+    gtk_combo_set_case_sensitive (GTK_COMBO (in_dialog->priv->templ_combo), TRUE);
     in_dialog->priv->templ_entry = GTK_COMBO (in_dialog->priv->templ_combo)->entry;
     gtk_signal_connect (GTK_OBJECT (in_dialog->priv->templ_entry),
                         "key-press-event", GTK_SIGNAL_FUNC (on_templ_entry_keypress),
@@ -1156,10 +1118,10 @@ init (GnomeCmdAdvrenameDialog *in_dialog)
     table_add (table, bbox, 0, 1, (GtkAttachOptions) (GTK_EXPAND|GTK_FILL));
     gtk_button_box_set_layout (GTK_BUTTON_BOX (bbox), GTK_BUTTONBOX_START);
 
-    btn = create_button_with_menu (in_dialog, _("Dir"), DIR_MENU);
+    btn = create_button_with_menu (in_dialog, _("Directory"), DIR_MENU);
     gtk_container_add (GTK_CONTAINER (bbox), btn);
 
-    btn = create_button_with_menu (in_dialog, _("Name"), NAME_MENU);
+    btn = create_button_with_menu (in_dialog, _("File"), FILE_MENU);
     gtk_container_add (GTK_CONTAINER (bbox), btn);
 
     btn = create_button_with_menu (in_dialog, _("Counter"),COUNTER_MENU);
@@ -1192,14 +1154,14 @@ init (GnomeCmdAdvrenameDialog *in_dialog)
     table_add (table, bbox, 0, 1, (GtkAttachOptions) (GTK_EXPAND|GTK_FILL));
     gtk_button_box_set_layout (GTK_BUTTON_BOX (bbox), GTK_BUTTONBOX_START);
 
-    in_dialog->priv->add_btn = create_button (dialog, _("_Add..."), GTK_SIGNAL_FUNC (on_rule_add));
+    in_dialog->priv->add_btn = create_stock_button (dialog, GTK_STOCK_ADD, GTK_SIGNAL_FUNC (on_rule_add));
     gtk_container_add (GTK_CONTAINER (bbox), in_dialog->priv->add_btn);
 
-    in_dialog->priv->edit_btn = create_button (dialog, _("_Edit..."), GTK_SIGNAL_FUNC (on_rule_edit));
+    in_dialog->priv->edit_btn = create_stock_button (dialog, GTK_STOCK_EDIT, GTK_SIGNAL_FUNC (on_rule_edit));
     gtk_container_add (GTK_CONTAINER (bbox), in_dialog->priv->edit_btn);
     gtk_widget_set_sensitive (GTK_WIDGET (in_dialog->priv->edit_btn), FALSE);
 
-    in_dialog->priv->remove_btn = create_button (dialog, _("_Remove"), GTK_SIGNAL_FUNC (on_rule_remove));
+    in_dialog->priv->remove_btn = create_stock_button (dialog, GTK_STOCK_REMOVE, GTK_SIGNAL_FUNC (on_rule_remove));
     gtk_container_add (GTK_CONTAINER (bbox), in_dialog->priv->remove_btn);
     gtk_widget_set_sensitive (GTK_WIDGET (in_dialog->priv->remove_btn), FALSE);
 
@@ -1228,8 +1190,8 @@ init (GnomeCmdAdvrenameDialog *in_dialog)
 
     sw = create_clist (dialog, "res_list", 2, 16, NULL, NULL);
     gtk_container_add (GTK_CONTAINER (vbox), sw);
-    create_clist_column (sw, 0, advrename_dialog_default_res_column_width[0], _("Current filenames"));
-    create_clist_column (sw, 1, advrename_dialog_default_res_column_width[1], _("New filenames"));
+    create_clist_column (sw, 0, advrename_dialog_default_res_column_width[0], _("Current file names"));
+    create_clist_column (sw, 1, advrename_dialog_default_res_column_width[1], _("New file names"));
     in_dialog->priv->res_list = lookup_widget (GTK_WIDGET (sw), "res_list");
 
 
@@ -1290,7 +1252,7 @@ GtkWidget *gnome_cmd_advrename_dialog_new (GList *files)
 }
 
 
-GtkType gnome_cmd_advrename_dialog_get_type         (void)
+GtkType gnome_cmd_advrename_dialog_get_type (void)
 {
     static GtkType dlg_type = 0;
 
