@@ -19,16 +19,16 @@
 
 #include <config.h>
 #include <sys/types.h>
-#include <regex.h>
 #include <unistd.h>
 #include <errno.h>
+
 #include "gnome-cmd-includes.h"
 #include "gnome-cmd-bookmark-dialog.h"
 #include "gnome-cmd-main-win.h"
+#include "gnome-cmd-con-list.h"
 #include "gnome-cmd-file-selector.h"
 #include "gnome-cmd-file.h"
 #include "gnome-cmd-clist.h"
-#include "gnome-cmd-dir.h"
 #include "gnome-cmd-data.h"
 #include "gnome-cmd-combo.h"
 #include "widget-factory.h"
@@ -302,15 +302,13 @@ static void on_dir_unselected (GtkCList *list, gint row, gint column, GdkEventBu
 }
 
 
-static void
-on_scroll_vertical (GtkCList *clist, GtkScrollType scroll_type, gfloat position, gpointer data)
+static void on_scroll_vertical (GtkCList *clist, GtkScrollType scroll_type, gfloat position, gpointer data)
 {
     gtk_clist_select_row (clist, clist->focus_row, 0);
 }
 
 
-static void
-add_groups (GnomeCmdBookmarkDialog *dialog)
+static void add_groups (GnomeCmdBookmarkDialog *dialog)
 {
     gchar *text[3];
 
@@ -329,8 +327,7 @@ add_groups (GnomeCmdBookmarkDialog *dialog)
 }
 
 
-static void
-add_bookmarks (GnomeCmdBookmarkDialog *dialog)
+static void add_bookmarks (GnomeCmdBookmarkDialog *dialog)
 {
     GnomeCmdCon *current_con = gnome_cmd_file_selector_get_connection (gnome_cmd_main_win_get_fs (main_win, ACTIVE));
     GnomeCmdBookmarkGroup *group, *current_group = NULL;
@@ -338,7 +335,7 @@ add_bookmarks (GnomeCmdBookmarkDialog *dialog)
     g_return_if_fail (current_con != NULL);
 
     // Then add bookmarks for all connections
-    for (GList *all_cons = gnome_cmd_con_list_get_all (gnome_cmd_data_get_con_list ()); all_cons; all_cons = all_cons->next)
+    for (GList *all_cons = gnome_cmd_con_list_get_all (gnome_cmd_con_list_get ()); all_cons; all_cons = all_cons->next)
     {
         GnomeCmdCon *con = (GnomeCmdCon *) all_cons->data;
         group = gnome_cmd_con_get_bookmarks (con);
@@ -358,8 +355,7 @@ add_bookmarks (GnomeCmdBookmarkDialog *dialog)
 }
 
 
-static void
-on_group_combo_item_selected (GnomeCmdCombo *group_combo, GnomeCmdBookmarkGroup *group, GnomeCmdBookmarkDialog *dialog)
+static void on_group_combo_item_selected (GnomeCmdCombo *group_combo, GnomeCmdBookmarkGroup *group, GnomeCmdBookmarkDialog *dialog)
 {
     g_return_if_fail (group != NULL);
 
@@ -367,13 +363,23 @@ on_group_combo_item_selected (GnomeCmdCombo *group_combo, GnomeCmdBookmarkGroup
 }
 
 
-static void
-on_column_resize (GtkCList *clist, gint column, gint width, GnomeCmdBookmarkDialog *dialog)
+static void on_column_resize (GtkCList *clist, gint column, gint width, GnomeCmdBookmarkDialog *dialog)
 {
     gnome_cmd_data_set_bookmark_dialog_col_width (column, width);
 }
 
 
+static gint bookmark_dlg_width = 500;
+static gint bookmark_dlg_height = 500;
+
+
+static void on_dialog_size_allocate (GtkWidget *widget, GtkAllocation *allocation, GnomeCmdBookmarkDialog *dialog)
+{
+    bookmark_dlg_width = allocation->width;
+    bookmark_dlg_height = allocation->height;
+}
+
+
 /*******************************
  * Gtk class implementation
  *******************************/
@@ -424,14 +430,19 @@ init (GnomeCmdBookmarkDialog *in_dialog)
     GtkWidget *dir_list;
     GtkAccelGroup *accel_group = gtk_accel_group_new ();
 
-    in_dialog->priv = g_new (GnomeCmdBookmarkDialogPrivate, 1);
+    in_dialog->priv = g_new0 (GnomeCmdBookmarkDialogPrivate, 1);
+
     in_dialog->priv->groups = NULL;
 
     dialog = GTK_WIDGET (in_dialog);
     gtk_object_set_data (GTK_OBJECT (dialog), "dialog", dialog);
-    gtk_widget_set_size_request (GTK_WIDGET (dialog), 400, 400);
-    gtk_window_set_default_size (GTK_WINDOW (dialog), 500, 400);
     gtk_window_set_title (GTK_WINDOW (dialog), _("Bookmarks"));
+    gtk_widget_set_size_request (GTK_WIDGET (dialog), 400, 400);
+    gtk_window_set_default_size (GTK_WINDOW (dialog), bookmark_dlg_width, bookmark_dlg_height);
+    gtk_window_set_resizable (GTK_WINDOW (dialog), TRUE);
+    gtk_window_set_policy (GTK_WINDOW (dialog), FALSE, TRUE, FALSE);
+    gtk_signal_connect (GTK_OBJECT (dialog), "size-allocate",
+                        GTK_SIGNAL_FUNC (on_dialog_size_allocate), dialog);
 
     vbox = create_vbox (dialog, FALSE, 12);
     cat = create_category (dialog, vbox, _("Bookmark Groups"));
@@ -458,17 +469,17 @@ init (GnomeCmdBookmarkDialog *in_dialog)
     bbox = create_vbox (dialog, FALSE, 12);
     gtk_box_pack_start (GTK_BOX (hbox), bbox, FALSE, FALSE, 0);
 
-    in_dialog->priv->goto_btn = create_named_button (dialog, _("_Goto"), "goto_button", GTK_SIGNAL_FUNC (on_dir_goto));
+    in_dialog->priv->goto_btn = create_named_stock_button (dialog, GTK_STOCK_JUMP_TO, "goto_button", GTK_SIGNAL_FUNC (on_dir_goto));
     GTK_WIDGET_SET_FLAGS (in_dialog->priv->goto_btn, GTK_CAN_DEFAULT);
     gtk_box_pack_start (GTK_BOX (bbox), in_dialog->priv->goto_btn, FALSE, TRUE, 0);
     gtk_widget_set_sensitive (GTK_WIDGET (in_dialog->priv->goto_btn), FALSE);
 
-    in_dialog->priv->edit_btn = create_named_button (dialog, _("_Edit"), "edit_button", GTK_SIGNAL_FUNC (on_dir_edit));
+    in_dialog->priv->edit_btn = create_named_stock_button (dialog, GTK_STOCK_EDIT, "edit_button", GTK_SIGNAL_FUNC (on_dir_edit));
     GTK_WIDGET_SET_FLAGS (in_dialog->priv->edit_btn, GTK_CAN_DEFAULT);
     gtk_box_pack_start (GTK_BOX (bbox), in_dialog->priv->edit_btn, FALSE, TRUE, 0);
     gtk_widget_set_sensitive (GTK_WIDGET (in_dialog->priv->edit_btn), FALSE);
 
-    in_dialog->priv->remove_btn = create_named_button (dialog, _("_Remove"), "remove_button", GTK_SIGNAL_FUNC (on_dir_remove));
+    in_dialog->priv->remove_btn = create_named_stock_button (dialog, GTK_STOCK_REMOVE, "remove_button", GTK_SIGNAL_FUNC (on_dir_remove));
     GTK_WIDGET_SET_FLAGS (in_dialog->priv->remove_btn, GTK_CAN_DEFAULT);
     gtk_box_pack_start (GTK_BOX (bbox), in_dialog->priv->remove_btn, FALSE, TRUE, 0);
     gtk_widget_set_sensitive (GTK_WIDGET (in_dialog->priv->remove_btn), FALSE);
@@ -552,7 +563,7 @@ gnome_cmd_bookmark_dialog_new (void)
 static gboolean
 on_new_bookmark_ok (GnomeCmdStringDialog *string_dialog, const gchar **values, gpointer data)
 {
-    GnomeCmdBookmark *bookmark = g_new (GnomeCmdBookmark, 1);
+    GnomeCmdBookmark *bookmark = g_new0 (GnomeCmdBookmark, 1);
     GnomeCmdCon *con = gnome_cmd_file_selector_get_connection (gnome_cmd_main_win_get_fs (main_win, ACTIVE));
     GnomeCmdBookmarkGroup *group = gnome_cmd_con_get_bookmarks (con);
 
@@ -589,34 +600,34 @@ gnome_cmd_bookmark_add_current (void)
 }
 
 
-void
-gnome_cmd_bookmark_goto (GnomeCmdBookmark *bookmark)
+void gnome_cmd_bookmark_goto (GnomeCmdBookmark *bookmark)
 {
-    GnomeCmdCon *current_con;
     GnomeCmdFileSelector *fs = gnome_cmd_main_win_get_fs (main_win, ACTIVE);
-
     g_return_if_fail (GNOME_CMD_IS_FILE_SELECTOR (fs));
 
-    current_con = gnome_cmd_file_selector_get_connection (fs);
+    GnomeCmdCon *current_con = gnome_cmd_file_selector_get_connection (fs);
     g_return_if_fail (bookmark->group->con != NULL);
 
     if (current_con == bookmark->group->con)
         gnome_cmd_file_selector_goto_directory (fs, bookmark->path);
-    else {
+    else
+    {
         GnomeCmdCon *con = bookmark->group->con;
 
-        if (con->state == CON_STATE_OPEN) {
+        if (con->state == CON_STATE_OPEN)
+        {
             GnomeCmdDir *dir = gnome_cmd_dir_new (con, gnome_cmd_con_create_path (con, bookmark->path));
             gnome_cmd_file_selector_set_connection (fs, con, dir);
 
         }
-        else {
+        else
+        {
             if (con->base_path)
                 gtk_object_unref (GTK_OBJECT (con->base_path));
 
             con->base_path = gnome_cmd_con_create_path (con, bookmark->path);
             gtk_object_ref (GTK_OBJECT (con->base_path));
-            gnome_cmd_file_selector_set_connection (fs, con, NULL);
+            gnome_cmd_file_selector_set_connection (fs, con);
         }
     }
 }
