@@ -16,14 +16,10 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
-#ifndef __GNOME_CMD_PREPARE_DEL_DIALOG_H__
-#define __GNOME_CMD_PREPARE_DEL_DIALOG_H__
-
-G_BEGIN_DECLS
+#ifndef __GNOME_CMD_DELETE_DIALOG_H__
+#define __GNOME_CMD_DELETE_DIALOG_H__
 
 void
 gnome_cmd_delete_dialog_show (GList *files);
 
-G_END_DECLS
-
-#endif // __GNOME_CMD_PREPARE_DEL_DIALOG_H__
+#endif // __GNOME_CMD_DELETE_DIALOG_H__
