@@ -75,10 +75,6 @@ static GnomeCmdCListClass *parent_class = NULL;
 
 static guint file_list_signals[LAST_SIGNAL] = { 0 };
 
-GList *gnome_vfs_list_sort (GList *list,
-                            GnomeVFSListCompareFunc compare_func,
-                            gpointer data);
-
 static gint sort_by_name (GnomeCmdFile *f1, GnomeCmdFile *f2, GnomeCmdFileList *fl);
 static gint sort_by_ext (GnomeCmdFile *f1, GnomeCmdFile *f2, GnomeCmdFileList *fl);
 static gint sort_by_dir (GnomeCmdFile *f1, GnomeCmdFile *f2, GnomeCmdFileList *fl);
@@ -91,14 +87,14 @@ static gint sort_by_group (GnomeCmdFile *f1, GnomeCmdFile *f2, GnomeCmdFileList
 
 GnomeCmdFileListColumn file_list_column[FILE_LIST_NUM_COLUMNS] =
 {{FILE_LIST_COLUMN_ICON,"",16,GTK_JUSTIFY_CENTER,FILE_LIST_SORT_ASCENDING,NULL},
- {FILE_LIST_COLUMN_NAME,N_("name"),140,GTK_JUSTIFY_LEFT,FILE_LIST_SORT_ASCENDING,(GnomeVFSListCompareFunc)sort_by_name},
- {FILE_LIST_COLUMN_EXT,N_("ext"),40,GTK_JUSTIFY_LEFT,FILE_LIST_SORT_ASCENDING,(GnomeVFSListCompareFunc)sort_by_ext},
- {FILE_LIST_COLUMN_DIR,N_("dir"),240,GTK_JUSTIFY_LEFT,FILE_LIST_SORT_ASCENDING,(GnomeVFSListCompareFunc)sort_by_dir},
- {FILE_LIST_COLUMN_SIZE,N_("size"),70,GTK_JUSTIFY_RIGHT,FILE_LIST_SORT_DESCENDING,(GnomeVFSListCompareFunc)sort_by_size},
- {FILE_LIST_COLUMN_DATE,N_("date"),150,GTK_JUSTIFY_CENTER,FILE_LIST_SORT_DESCENDING,(GnomeVFSListCompareFunc)sort_by_date},
- {FILE_LIST_COLUMN_PERM,N_("perm"),70,GTK_JUSTIFY_LEFT,FILE_LIST_SORT_ASCENDING,(GnomeVFSListCompareFunc)sort_by_perm},
- {FILE_LIST_COLUMN_OWNER,N_("uid"),50,GTK_JUSTIFY_LEFT,FILE_LIST_SORT_ASCENDING,(GnomeVFSListCompareFunc)sort_by_owner},
- {FILE_LIST_COLUMN_GROUP,N_("gid"),50,GTK_JUSTIFY_LEFT,FILE_LIST_SORT_ASCENDING,(GnomeVFSListCompareFunc)sort_by_group}};
+ {FILE_LIST_COLUMN_NAME, N_("name"), 140, GTK_JUSTIFY_LEFT, FILE_LIST_SORT_ASCENDING, (GCompareDataFunc) sort_by_name},
+ {FILE_LIST_COLUMN_EXT, N_("ext"), 40, GTK_JUSTIFY_LEFT, FILE_LIST_SORT_ASCENDING, (GCompareDataFunc) sort_by_ext},
+ {FILE_LIST_COLUMN_DIR, N_("dir"), 240, GTK_JUSTIFY_LEFT, FILE_LIST_SORT_ASCENDING, (GCompareDataFunc) sort_by_dir},
+ {FILE_LIST_COLUMN_SIZE, N_("size"), 70, GTK_JUSTIFY_RIGHT, FILE_LIST_SORT_DESCENDING, (GCompareDataFunc) sort_by_size},
+ {FILE_LIST_COLUMN_DATE, N_("date"), 150, GTK_JUSTIFY_LEFT, FILE_LIST_SORT_DESCENDING, (GCompareDataFunc) sort_by_date},
+ {FILE_LIST_COLUMN_PERM, N_("perm"), 70, GTK_JUSTIFY_LEFT, FILE_LIST_SORT_ASCENDING, (GCompareDataFunc) sort_by_perm},
+ {FILE_LIST_COLUMN_OWNER, N_("uid"), 50, GTK_JUSTIFY_LEFT, FILE_LIST_SORT_ASCENDING, (GCompareDataFunc) sort_by_owner},
+ {FILE_LIST_COLUMN_GROUP, N_("gid"), 50, GTK_JUSTIFY_LEFT, FILE_LIST_SORT_ASCENDING, (GCompareDataFunc) sort_by_group}};
 
 
 struct _GnomeCmdFileListPrivate
@@ -107,7 +103,7 @@ struct _GnomeCmdFileListPrivate
     GtkWidget *column_labels[FILE_LIST_NUM_COLUMNS];
     GtkWidget *popup_menu;
 
-    GnomeVFSListCompareFunc sort_func;
+    GCompareDataFunc sort_func;
     gint current_col;
     gboolean sort_raising[FILE_LIST_NUM_COLUMNS];
     GnomeCmdFileCollection *shown_files;
@@ -165,9 +161,9 @@ static void on_selpat_hide (GtkWidget *dialog, GnomeCmdFileList *fl)
 }
 
 
-static void show_selpat_dialog (GnomeCmdFileList *fl, gboolean mode)
+inline void show_selpat_dialog (GnomeCmdFileList *fl, gboolean mode)
 {
-    if (fl->priv->selpat_dialog) return;
+    if (fl->priv->selpat_dialog)  return;
 
     GtkWidget *dialog = gnome_cmd_patternsel_dialog_new (fl, mode);
 
@@ -208,9 +204,8 @@ inline void focus_file_at_row (GnomeCmdFileList *fl, gint row)
     g_return_if_fail (GNOME_CMD_IS_FILE_LIST (fl));
 
     GTK_CLIST (fl)->focus_row = row;
-    fl->priv->cur_file = row;
     gtk_clist_select_row (GTK_CLIST (fl), row, 0);
-
+    fl->priv->cur_file = GTK_CLIST (fl)->focus_row;
 }
 
 
@@ -405,10 +400,9 @@ static void toggle_files_with_same_extension (GnomeCmdFileList *fl, gboolean sel
 
 inline void toggle_with_pattern (GnomeCmdFileList *fl, const gchar *pattern, gboolean case_sens, gboolean mode)
 {
-
     g_return_if_fail (GNOME_CMD_IS_FILE_LIST (fl));
 
-    Filter *filter = filter_new (pattern, case_sens);
+    Filter *filter = filter_new (pattern, case_sens, gnome_cmd_data_get_filter_type ());
     g_return_if_fail (filter != NULL);
 
     for (GList *tmp=gnome_cmd_file_list_get_all_files (fl); tmp; tmp = tmp->next)
@@ -510,7 +504,6 @@ static char *build_selected_file_list (GnomeCmdFileList *fl, int *file_list_len)
 
     if (listlen > 1)
     {
-        char *data, *copy;
         int total_len = 0;
         GList *tmp = sel_files;
         GList *uri_str_list = NULL;
@@ -541,6 +534,9 @@ static char *build_selected_file_list (GnomeCmdFileList *fl, int *file_list_len)
 
         // allocate memory
         total_len++;
+
+        char *data, *copy;
+
         data = copy = (gchar *) g_malloc (total_len+1);
 
         // put the uri_str_list in the allocated memory
@@ -620,7 +616,7 @@ inline void init_dnd (GnomeCmdFileList *fl)
     g_return_if_fail (GNOME_CMD_IS_FILE_LIST (fl));
 
     gtk_drag_source_set (GTK_WIDGET (fl), GDK_BUTTON1_MASK,
-                         drag_types, ELEMENTS (drag_types),
+                         drag_types, G_N_ELEMENTS (drag_types),
                          (GdkDragAction) (GDK_ACTION_LINK | GDK_ACTION_MOVE | GDK_ACTION_COPY | GDK_ACTION_ASK | GDK_ACTION_DEFAULT));
 
     gtk_signal_connect (GTK_OBJECT (fl), "drag_data_get", GTK_SIGNAL_FUNC (drag_data_get), fl);
@@ -668,8 +664,8 @@ static gboolean on_right_mb_timeout (GnomeCmdFileList *fl)
 
     if (fl->priv->right_mb_down_file == focus_file)
     {
+        select_file (fl, focus_file);
         show_file_popup (fl, NULL);
-        toggle_file (fl, focus_file);
         return FALSE;
     }
 
@@ -1066,7 +1062,7 @@ on_file_clicked (GnomeCmdFileList *fl,
 
                     fl->priv->right_mb_down_file = finfo;
                     fl->priv->right_mb_timeout_id =
-                        gtk_timeout_add (POPUP_TIMEOUT, (GtkFunction)on_right_mb_timeout, fl);
+                        gtk_timeout_add (POPUP_TIMEOUT, (GtkFunction) on_right_mb_timeout, fl);
                 }
                 else
                     show_file_popup (fl, event);
@@ -1230,15 +1226,15 @@ static void init (GnomeCmdFileList *fl)
     gint i;
     gboolean b;
 
-    fl->priv = g_new (GnomeCmdFileListPrivate, 1);
+    fl->priv = g_new0 (GnomeCmdFileListPrivate, 1);
     fl->priv->shown_files = gnome_cmd_file_collection_new ();
-    fl->priv->selected_files = NULL;
-    fl->priv->shift_down = FALSE;
-    fl->priv->selpat_dialog = NULL;
-    fl->priv->right_mb_down_file = NULL;
-    fl->priv->right_mb_timeout_id = 0;
-    fl->priv->quicksearch_popup = NULL;
-    fl->priv->focus_later = NULL;
+    // fl->priv->selected_files = NULL;
+    // fl->priv->shift_down = FALSE;
+    // fl->priv->selpat_dialog = NULL;
+    // fl->priv->right_mb_down_file = NULL;
+    // fl->priv->right_mb_timeout_id = 0;
+    // fl->priv->quicksearch_popup = NULL;
+    // fl->priv->focus_later = NULL;
 
     for (i=0; i<FILE_LIST_NUM_COLUMNS; i++)
         fl->priv->sort_raising[i] = FALSE;
@@ -1311,6 +1307,14 @@ void gnome_cmd_file_list_show_column (GnomeCmdFileList *fl, GnomeCmdFileListColu
 }
 
 
+GnomeCmdFileListColumnID gnome_cmd_file_list_get_sort_column (GnomeCmdFileList *fl)
+{
+    g_return_val_if_fail (GNOME_CMD_IS_FILE_LIST (fl), FILE_LIST_COLUMN_ICON);
+
+    return (GnomeCmdFileListColumnID) fl->priv->current_col;
+}
+
+
 void gnome_cmd_file_list_update_style (GnomeCmdFileList *fl)
 {
     gtk_clist_set_row_height (GTK_CLIST (fl), gnome_cmd_data_get_list_row_height ());
@@ -1478,7 +1482,7 @@ void gnome_cmd_file_list_show_files (GnomeCmdFileList *fl, GList *files, gboolea
     list = g_list_copy (files);
 
     if (sort)
-        tmp = list = gnome_vfs_list_sort (list, (GnomeVFSListCompareFunc)fl->priv->sort_func, fl);
+        tmp = list = g_list_sort_with_data (list, (GCompareDataFunc) fl->priv->sort_func, fl);
     else
         tmp = list;
 
@@ -1556,13 +1560,15 @@ void gnome_cmd_file_list_remove_file (GnomeCmdFileList *fl, GnomeCmdFile *finfo)
     g_return_if_fail (finfo != NULL);
 
     gint row = get_row_from_file (fl, finfo);
+
     if (row >= 0)
     {
         gtk_clist_remove (GTK_CLIST (fl), row);
+
         fl->priv->selected_files = g_list_remove (fl->priv->selected_files, finfo);
         gnome_cmd_file_collection_remove (fl->priv->shown_files, finfo);
 
-        focus_file_at_row (fl, MIN(row, GTK_CLIST(fl)->focus_row));
+        focus_file_at_row (fl, MIN (row, GTK_CLIST(fl)->focus_row));
     }
 }
 
@@ -1803,10 +1809,7 @@ void gnome_cmd_file_list_toggle_and_step (GnomeCmdFileList *fl)
 }
 
 
-void
-gnome_cmd_file_list_focus_file (GnomeCmdFileList *fl,
-                                const gchar *focus_file,
-                                gboolean scroll_to_file)
+void gnome_cmd_file_list_focus_file (GnomeCmdFileList *fl, const gchar *focus_file, gboolean scroll_to_file)
 {
     g_return_if_fail (GNOME_CMD_IS_FILE_LIST (fl));
 
@@ -1833,8 +1836,7 @@ gnome_cmd_file_list_focus_file (GnomeCmdFileList *fl,
 
     /* The file was not found, remember the filename in case the file gets
        added to the list in the future (after a FAM event etc). */
-    if (fl->priv->focus_later)
-        g_free (fl->priv->focus_later);
+    g_free (fl->priv->focus_later);
     fl->priv->focus_later = g_strdup (focus_file);
 }
 
@@ -1955,41 +1957,27 @@ void gnome_cmd_file_list_compare_directories (void)
 
 void gnome_cmd_file_list_sort (GnomeCmdFileList *fl)
 {
-    GList *list;
-    GnomeCmdFile *selfile;
-    gint selrow;
-
     g_return_if_fail (GNOME_CMD_IS_FILE_LIST (fl));
 
-    selfile = gnome_cmd_file_list_get_selected_file (fl);
+    GnomeCmdFile *selfile = gnome_cmd_file_list_get_selected_file (fl);
 
     gtk_clist_freeze (GTK_CLIST (fl));
     gtk_clist_clear (GTK_CLIST (fl));
 
     // Resort the files and readd them to the list
-    list = gnome_cmd_file_list_get_all_files (fl);
-    list = gnome_vfs_list_sort (list, fl->priv->sort_func, fl);
-    while (list != NULL)
-    {
-        GnomeCmdFile *finfo;
+    for (GList *list = gnome_cmd_file_collection_sort (fl->priv->shown_files, fl->priv->sort_func, fl); list; list = list->next)
+        add_file_to_clist (fl, GNOME_CMD_FILE (list->data), -1);
 
-        finfo = GNOME_CMD_FILE (list->data);
-        add_file_to_clist (fl, finfo, -1);
-        list = list->next;
-    }
-    g_list_free (list);
-
-    /* refocus the previously selected file if this
-       file-list has the focus */
+    // refocus the previously selected file if this file-list has the focus
     if (selfile && GTK_WIDGET_HAS_FOCUS (fl))
     {
-        selrow = get_row_from_file (fl, selfile);
+        gint selrow = get_row_from_file (fl, selfile);
         gnome_cmd_file_list_select_row (fl, selrow);
         gtk_clist_moveto (GTK_CLIST (fl), selrow, -1, 1, 0);
     }
 
     // reselect the previously selected files
-    for (list = fl->priv->selected_files; list != NULL; list = list->next)
+    for (GList *list = fl->priv->selected_files; list; list = list->next)
         select_file (fl, GNOME_CMD_FILE (list->data));
 
     gtk_clist_thaw (GTK_CLIST (fl));
@@ -2012,14 +2000,14 @@ void gnome_cmd_file_list_show_rename_dialog (GnomeCmdFileList *fl)
 {
     g_return_if_fail (GNOME_CMD_IS_FILE_LIST (fl));
 
-    GnomeCmdFile *finfo;
-    gint x, y, w, h;
-
-    finfo = gnome_cmd_file_list_get_selected_file (fl);
+    GnomeCmdFile *finfo = gnome_cmd_file_list_get_selected_file (fl);
 
     if (GNOME_CMD_IS_FILE (finfo))
     {
-        get_focus_row_coordinates(fl, &x, &y, &w, &h);
+        gint x, y, w, h;
+
+        get_focus_row_coordinates (fl, &x, &y, &w, &h);
+
         GtkWidget *dialog = gnome_cmd_rename_dialog_new (finfo, x, y, w, h);
 
         gtk_widget_ref (dialog);
@@ -2403,67 +2391,9 @@ gboolean gnome_cmd_file_list_keypressed (GnomeCmdFileList *fl, GdkEventKey *even
 }
 
 
-static GList *gnome_vfs_list_sort_merge (GList *l1, GList *l2, GnomeVFSListCompareFunc compare_func, gpointer data)
-{
-    GList list;
-    GList *l = &list;
-    GList  *lprev = NULL;
-
-    while (l1 && l2)
-    {
-        if (compare_func (l1->data, l2->data, data) < 0)
-        {
-            l->next = l1;
-            l = l->next;
-            l->prev = lprev;
-            lprev = l;
-            l1 = l1->next;
-        }
-        else
-        {
-            l->next = l2;
-            l = l->next;
-            l->prev = lprev;
-            lprev = l;
-            l2 = l2->next;
-        }
-    }
-
-    l->next = l1 ? l1 : l2;
-    l->next->prev = l;
-
-    return list.next;
-}
-
-
-GList *gnome_vfs_list_sort (GList *list, GnomeVFSListCompareFunc compare_func, gpointer data)
-{
-    if (!list || !list->next)
-        return list;
-
-    GList *l1 = list;
-    GList *l2 = list->next;
-
-    while ((l2 = l2->next) != NULL)
-    {
-        if ((l2 = l2->next) == NULL)
-            break;
-        l1 = l1->next;
-    }
-
-    l2 = l1->next;
-    l1->next = NULL;
-
-    return gnome_vfs_list_sort_merge(gnome_vfs_list_sort (list, compare_func, data),
-                                     gnome_vfs_list_sort (l2, compare_func, data),
-                                     compare_func,
-                                     data);
-}
-
-
 GList *gnome_cmd_file_list_sort_selection (GList *list, GnomeCmdFileList *fl)
 {
-    return gnome_vfs_list_sort(list, (GnomeVFSListCompareFunc)fl->priv->sort_func, fl);
+    return g_list_sort_with_data (list, (GCompareDataFunc) fl->priv->sort_func, fl);
 }
 
 
