@@ -34,6 +34,7 @@
 #include "gnome-cmd-dir.h"
 #include "gnome-cmd-plain-path.h"
 #include "gnome-cmd-con.h"
+#include "gnome-cmd-con-list.h"
 #include "gnome-cmd-bookmark-dialog.h"
 #include "utils.h"
 
@@ -47,14 +48,25 @@ enum {SWITCH_FS, LAST_SIGNAL};
 
 enum
 {
-  TOOLBAR_BTN_FIRST = 2,
-  TOOLBAR_BTN_BACK = 3,
-  TOOLBAR_BTN_FORWARD = 4,
-  TOOLBAR_BTN_LAST = 5,
-  TOOLBAR_BTN_CUT = 8,
-  TOOLBAR_BTN_COPY = 9,
-  TOOLBAR_BTN_PASTE = 10,
-  TOOLBAR_BTN_DISCONNECT = 16
+  TOOLBAR_BTN_REFRESH,
+  TOOLBAR_BTN_UP,
+  TOOLBAR_BTN_FIRST,
+  TOOLBAR_BTN_BACK,
+  TOOLBAR_BTN_FORWARD,
+  TOOLBAR_BTN_LAST,
+  TOOLBAR_BTN_SEP_0,
+  TOOLBAR_BTN_COPY_FILENAMES,
+  TOOLBAR_BTN_CUT,
+  TOOLBAR_BTN_COPY,
+  TOOLBAR_BTN_PASTE,
+  TOOLBAR_BTN_DELETE,
+  TOOLBAR_BTN_SEP_1,
+  TOOLBAR_BTN_EDIT,
+  TOOLBAR_BTN_MAIL,
+  TOOLBAR_BTN_TERMINAL,
+  TOOLBAR_BTN_SEP_2,
+  TOOLBAR_BTN_CONNECT,
+  TOOLBAR_BTN_DISCONNECT
 };
 
 
@@ -103,15 +115,13 @@ static GnomeAppClass *parent_class = NULL;
 
 static guint main_win_signals[LAST_SIGNAL] = { 0 };
 static GtkTooltips *toolbar_tooltips = NULL;
-extern gchar *start_dir_left;   //main.c
-extern gchar *start_dir_right;  //main.c
+extern gchar *start_dir_left;   //main.cc
+extern gchar *start_dir_right;  //main.cc
 
-static void
-gnome_cmd_main_win_real_switch_fs (GnomeCmdMainWin *mw, GnomeCmdFileSelector *fs);
+static void gnome_cmd_main_win_real_switch_fs (GnomeCmdMainWin *mw, GnomeCmdFileSelector *fs);
 
 
-gint gnome_cmd_key_snooper(GtkWidget *grab_widget,
-            GdkEventKey *event, GnomeCmdMainWin *mw)
+gint gnome_cmd_key_snooper(GtkWidget *grab_widget, GdkEventKey *event, GnomeCmdMainWin *mw)
 {
     g_return_val_if_fail(mw!=NULL, FALSE);
     g_return_val_if_fail(mw->priv!=NULL,FALSE);
@@ -165,8 +175,7 @@ inline GtkWidget *add_buttonbar_button (char *label,
 }
 
 
-static GtkWidget *
-create_separator (gboolean vertical)
+static GtkWidget *create_separator (gboolean vertical)
 {
     GtkWidget *sep;
     GtkWidget *box;
@@ -194,8 +203,7 @@ create_separator (gboolean vertical)
 }
 
 
-static void
-create_toolbar (GnomeCmdMainWin *mw, GnomeUIInfo *uiinfo)
+static void create_toolbar (GnomeCmdMainWin *mw, GnomeUIInfo *uiinfo)
 {
     gint i;
 
@@ -255,63 +263,55 @@ create_toolbar (GnomeCmdMainWin *mw, GnomeUIInfo *uiinfo)
 }
 
 
-static void
-slide_set_100_0 (GtkMenu *menu, gpointer user_data)
+static void slide_set_100_0 (GtkMenu *menu, gpointer user_data)
 {
     gtk_paned_set_position (GTK_PANED (main_win->priv->paned),
                             GTK_WIDGET (main_win)->allocation.width);
 }
 
 
-static void
-slide_set_80_20 (GtkMenu *menu, gpointer user_data)
+static void slide_set_80_20 (GtkMenu *menu, gpointer user_data)
 {
     gtk_paned_set_position (GTK_PANED (main_win->priv->paned),
                             (int)(GTK_WIDGET (main_win)->allocation.width*0.8f));
 }
 
 
-static void
-slide_set_60_40 (GtkMenu *menu, gpointer user_data)
+static void slide_set_60_40 (GtkMenu *menu, gpointer user_data)
 {
     gtk_paned_set_position (GTK_PANED (main_win->priv->paned),
                             (int)(GTK_WIDGET (main_win)->allocation.width*0.6f));
 }
 
 
-static void
-slide_set_50_50 (GtkMenu *menu, gpointer user_data)
+static void slide_set_50_50 (GtkMenu *menu, gpointer user_data)
 {
     gtk_paned_set_position (GTK_PANED (main_win->priv->paned),
                             (int)(GTK_WIDGET (main_win)->allocation.width*0.5f));
 }
 
 
-static void
-slide_set_40_60 (GtkMenu *menu, gpointer user_data)
+static void slide_set_40_60 (GtkMenu *menu, gpointer user_data)
 {
     gtk_paned_set_position (GTK_PANED (main_win->priv->paned),
                             (int)(GTK_WIDGET (main_win)->allocation.width*0.4f));
 }
 
 
-static void
-slide_set_20_80 (GtkMenu *menu, gpointer user_data)
+static void slide_set_20_80 (GtkMenu *menu, gpointer user_data)
 {
     gtk_paned_set_position (GTK_PANED (main_win->priv->paned),
                             (int)(GTK_WIDGET (main_win)->allocation.width*0.2f));
 }
 
 
-static void
-slide_set_0_100 (GtkMenu *menu, gpointer user_data)
+static void slide_set_0_100 (GtkMenu *menu, gpointer user_data)
 {
     gtk_paned_set_position (GTK_PANED (main_win->priv->paned), 0);
 }
 
 
-static GtkWidget *
-create_slide_popup ()
+static GtkWidget *create_slide_popup ()
 {
     static GnomeUIInfo popmenu_uiinfo[] =
     {
@@ -327,9 +327,7 @@ create_slide_popup ()
 
     // Set default callback data
 
-    guint i;
-
-    for (i = 0; popmenu_uiinfo[i].type != GNOME_APP_UI_ENDOFINFO; ++i)
+    for (guint i = 0; popmenu_uiinfo[i].type != GNOME_APP_UI_ENDOFINFO; ++i)
         if (popmenu_uiinfo[i].type == GNOME_APP_UI_ITEM)
             popmenu_uiinfo[i].user_data = main_win;
 
@@ -349,88 +347,67 @@ create_slide_popup ()
     Buttonbar callbacks
 *****************************************************************************/
 
-static void
-on_help_clicked                        (GtkButton       *button,
-                                        GnomeCmdMainWin *mw)
+static void on_help_clicked (GtkButton *button, GnomeCmdMainWin *mw)
 {
     help_help (NULL, mw);
 }
 
 
-static void
-on_rename_clicked                      (GtkButton       *button,
-                                        GnomeCmdMainWin *mw)
+static void on_rename_clicked (GtkButton *button, GnomeCmdMainWin *mw)
 {
     file_rename (NULL, mw);
 }
 
 
-static void
-on_view_clicked                        (GtkButton       *button,
-                                        GnomeCmdMainWin *mw)
+static void on_view_clicked (GtkButton *button, GnomeCmdMainWin *mw)
 {
     file_view (NULL, mw);
 }
 
 
-static void
-on_edit_clicked                        (GtkButton       *button,
-                                        GnomeCmdMainWin *mw)
+static void on_edit_clicked (GtkButton *button, GnomeCmdMainWin *mw)
 {
     file_edit (NULL, mw);
 }
 
 
-static void
-on_copy_clicked                        (GtkButton       *button,
-                                        GnomeCmdMainWin *mw)
+static void on_copy_clicked (GtkButton *button, GnomeCmdMainWin *mw)
 {
     file_copy (NULL, mw);
 }
 
 
-static void
-on_move_clicked                        (GtkButton       *button,
-                                        GnomeCmdMainWin *mw)
+static void on_move_clicked (GtkButton *button, GnomeCmdMainWin *mw)
 {
     file_move (NULL, mw);
 }
 
 
-static void
-on_mkdir_clicked                       (GtkButton       *button,
-                                        GnomeCmdMainWin *mw)
+static void on_mkdir_clicked(GtkButton *button, GnomeCmdMainWin *mw)
 {
     file_mkdir (NULL, mw);
 }
 
 
-static void
-on_delete_clicked                      (GtkButton       *button,
-                                        GnomeCmdMainWin *mw)
+static void on_delete_clicked (GtkButton *button, GnomeCmdMainWin *mw)
 {
     file_delete (NULL, mw);
 }
 
 
-static void
-on_search_clicked                      (GtkButton       *button,
-                                        GnomeCmdMainWin *mw)
+static void on_search_clicked (GtkButton *button, GnomeCmdMainWin *mw)
 {
     edit_search (NULL, mw);
 }
 
 
-static void
-on_quit_clicked                        (GtkButton       *button,
-                                        GnomeCmdMainWin *mw)
+static void on_quit_clicked (GtkButton *button, GnomeCmdMainWin *mw)
 {
     file_exit (NULL, mw);
 }
 
 
-static void
-create_buttonbar (GnomeCmdMainWin *mw)
+static void create_buttonbar (GnomeCmdMainWin *mw)
 {
     mw->priv->buttonbar_sep = create_separator (FALSE);
 
@@ -471,8 +448,7 @@ create_buttonbar (GnomeCmdMainWin *mw)
     Misc widgets callbacks
 *****************************************************************************/
 
-static gboolean
-on_slide_button_press (GtkWidget *widget, GdkEventButton *event, GnomeCmdMainWin *mw)
+static gboolean on_slide_button_press (GtkWidget *widget, GdkEventButton *event, GnomeCmdMainWin *mw)
 {
     if (event->type == GDK_BUTTON_PRESS && event->button == 3) {
         GtkPaned *paned = GTK_PANED (mw->priv->paned);
@@ -488,9 +464,7 @@ on_slide_button_press (GtkWidget *widget, GdkEventButton *event, GnomeCmdMainWin
     return FALSE;
 }
 
-static void
-on_main_win_realize                    (GtkWidget       *widget,
-                                        GnomeCmdMainWin *mw)
+static void on_main_win_realize (GtkWidget *widget, GnomeCmdMainWin *mw)
 {
     gint w;
 
@@ -514,10 +488,7 @@ on_main_win_realize                    (GtkWidget       *widget,
 }
 
 
-static gboolean
-on_left_fs_select                      (GtkCList *list,
-                                        GdkEventButton *event,
-                                        GnomeCmdMainWin *mw)
+static gboolean on_left_fs_select (GtkCList *list, GdkEventButton *event, GnomeCmdMainWin *mw)
 {
         mw->priv->current_fs = LEFT;
 
@@ -528,10 +499,7 @@ on_left_fs_select                      (GtkCList *list,
 }
 
 
-static gboolean
-on_right_fs_select                     (GtkCList *list,
-                                        GdkEventButton *event,
-                                        GnomeCmdMainWin *mw)
+static gboolean on_right_fs_select (GtkCList *list, GdkEventButton *event, GnomeCmdMainWin *mw)
 {
     mw->priv->current_fs = RIGHT;
 
@@ -542,11 +510,7 @@ on_right_fs_select                     (GtkCList *list,
 }
 
 
-static void
-on_fs_list_resize_column            (GtkCList        *clist,
-                                     gint             column,
-                                     gint             width,
-                                     GtkCList        *other_clist)
+static void on_fs_list_resize_column (GtkCList *clist, gint column, gint width, GtkCList *other_clist)
 {
     static gboolean column_resize_lock = FALSE;
 
@@ -562,10 +526,7 @@ on_fs_list_resize_column            (GtkCList        *clist,
 }
 
 
-static void
-on_size_allocate                  (GtkWidget *widget,
-                                   GtkAllocation *allocation,
-                                   gpointer user_data)
+static void on_size_allocate (GtkWidget *widget, GtkAllocation *allocation, gpointer user_data)
 {
     switch(gnome_cmd_data_get_main_win_state())
     {
@@ -580,9 +541,7 @@ on_size_allocate                  (GtkWidget *widget,
 }
 
 
-static void
-update_browse_buttons             (GnomeCmdMainWin *mw,
-                                   GnomeCmdFileSelector *fs)
+inline void update_browse_buttons (GnomeCmdMainWin *mw, GnomeCmdFileSelector *fs)
 {
     g_return_if_fail (GNOME_CMD_IS_MAIN_WIN (mw));
     g_return_if_fail (GNOME_CMD_IS_FILE_SELECTOR (fs));
@@ -602,19 +561,15 @@ update_browse_buttons             (GnomeCmdMainWin *mw,
 }
 
 
-static void
-update_drop_con_button            (GnomeCmdMainWin *mw,
-                                   GnomeCmdFileSelector *fs)
+static void update_drop_con_button (GnomeCmdMainWin *mw, GnomeCmdFileSelector *fs)
 {
     g_return_if_fail (GNOME_CMD_IS_MAIN_WIN (mw));
     g_return_if_fail (GNOME_CMD_IS_FILE_SELECTOR (fs));
 
-    GtkWidget *btn;
-    GnomeCmdPixmap *pm;
-    GnomeCmdCon *con;
+    GnomeCmdPixmap *pm = NULL;
     static GtkWidget *prev_pixmap = NULL;
 
-    con = gnome_cmd_file_selector_get_connection (fs);
+    GnomeCmdCon *con = gnome_cmd_file_selector_get_connection (fs);
     if (!con)
         return;
 
@@ -622,7 +577,7 @@ update_drop_con_button            (GnomeCmdMainWin *mw,
         || (gnome_cmd_data_get_skip_mounting () && GNOME_CMD_IS_CON_DEVICE (con)))
         return;
 
-    btn = mw->priv->tb_con_drop_btn;
+    GtkWidget *btn = mw->priv->tb_con_drop_btn;
     g_return_if_fail (GTK_IS_BUTTON (btn));
 
     if (prev_pixmap)
@@ -632,9 +587,7 @@ update_drop_con_button            (GnomeCmdMainWin *mw,
     }
 
     if (gnome_cmd_con_is_closeable (con))
-    {
         pm = gnome_cmd_con_get_close_pixmap (con);
-    }
     else
     {
         gtk_widget_set_sensitive (btn, FALSE);
@@ -670,18 +623,14 @@ update_drop_con_button            (GnomeCmdMainWin *mw,
 }
 
 
-static void
-on_fs_dir_change                  (GnomeCmdFileSelector *fs,
-                                   const gchar dir,
-                                   GnomeCmdMainWin *mw)
+static void on_fs_dir_change (GnomeCmdFileSelector *fs, const gchar dir, GnomeCmdMainWin *mw)
 {
     update_browse_buttons (mw, fs);
     update_drop_con_button (mw, fs);
 }
 
 
-static void
-restore_size_and_pos (GnomeCmdMainWin *mw)
+static void restore_size_and_pos (GnomeCmdMainWin *mw)
 {
     gint w, h, x, y;
 
@@ -705,14 +654,13 @@ restore_size_and_pos (GnomeCmdMainWin *mw)
 }
 
 
-static void
-on_delete_event (GnomeCmdMainWin *mw, GdkEvent *event, gpointer user_data)
+static void on_delete_event (GnomeCmdMainWin *mw, GdkEvent *event, gpointer user_data)
 {
     file_exit (NULL, mw);
 }
 
-static gboolean
-on_window_state_event (GtkWidget *mw, GdkEventWindowState *event, gpointer user_data)
+
+static gboolean on_window_state_event (GtkWidget *mw, GdkEventWindowState *event, gpointer user_data)
 {
     gint x, y;
 
@@ -742,10 +690,9 @@ on_window_state_event (GtkWidget *mw, GdkEventWindowState *event, gpointer user_
  * Gtk class implementation
  *******************************/
 
-static void
-destroy (GtkObject *object)
+static void destroy (GtkObject *object)
 {
-    GnomeCmdCon *con_home = gnome_cmd_con_list_get_home (gnome_cmd_data_get_con_list ());
+    GnomeCmdCon *con_home = get_home_con ();
 
     if (main_win && main_win->priv && main_win->priv->key_snooper_id)
     {
@@ -765,16 +712,14 @@ destroy (GtkObject *object)
 }
 
 
-static void
-map (GtkWidget *widget)
+static void map (GtkWidget *widget)
 {
     if (GTK_WIDGET_CLASS (parent_class)->map != NULL)
         GTK_WIDGET_CLASS (parent_class)->map (widget);
 }
 
 
-static void
-class_init (GnomeCmdMainWinClass *klass)
+static void class_init (GnomeCmdMainWinClass *klass)
 {
     GtkObjectClass *object_class = GTK_OBJECT_CLASS (klass);
     GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
@@ -796,8 +741,7 @@ class_init (GnomeCmdMainWinClass *klass)
 }
 
 
-static void
-init (GnomeCmdMainWin *mw)
+static void init (GnomeCmdMainWin *mw)
 {
     /* It is very important that this global variable gets assigned here so that
      * child widgets to this window can use that variable when initializing
@@ -817,7 +761,7 @@ init (GnomeCmdMainWin *mw)
     mw->priv->file_selector[LEFT] = NULL;
     mw->priv->file_selector[RIGHT] = NULL;
 
-    gnome_app_construct (GNOME_APP (main_win), "gnome-commander", "GNOME Commander");
+    gnome_app_construct (GNOME_APP (main_win), "gnome-commander", _("GNOME Commander"));
     gtk_object_set_data (GTK_OBJECT (main_win), "main_win", main_win);
     restore_size_and_pos (mw);
     gtk_window_set_policy (GTK_WINDOW (main_win), TRUE, TRUE, FALSE);
@@ -872,42 +816,29 @@ init (GnomeCmdMainWin *mw)
     gtk_signal_connect (GTK_OBJECT (mw->priv->file_selector[LEFT]), "changed-dir", GTK_SIGNAL_FUNC (on_fs_dir_change), mw);
     gtk_signal_connect (GTK_OBJECT (mw->priv->file_selector[RIGHT]), "changed-dir", GTK_SIGNAL_FUNC (on_fs_dir_change), mw);
 
-    gtk_signal_connect (
-        GTK_OBJECT (GNOME_CMD_FILE_SELECTOR (mw->priv->file_selector[LEFT])->list),
-        "resize_column", GTK_SIGNAL_FUNC (on_fs_list_resize_column),
-        GNOME_CMD_FILE_SELECTOR (mw->priv->file_selector[RIGHT])->list);
-    gtk_signal_connect (
-        GTK_OBJECT (GNOME_CMD_FILE_SELECTOR (mw->priv->file_selector[RIGHT])->list),
-        "resize_column", GTK_SIGNAL_FUNC (on_fs_list_resize_column),
-        GNOME_CMD_FILE_SELECTOR (mw->priv->file_selector[LEFT])->list);
-    gtk_signal_connect (
-        GTK_OBJECT (GNOME_CMD_FILE_SELECTOR (mw->priv->file_selector[LEFT])->list),
-        "button_press_event", GTK_SIGNAL_FUNC (on_left_fs_select), mw);
-    gtk_signal_connect (
-        GTK_OBJECT (GNOME_CMD_FILE_SELECTOR (mw->priv->file_selector[RIGHT])->list),
-        "button_press_event", GTK_SIGNAL_FUNC (on_right_fs_select), mw);
-    gtk_signal_connect (
-        GTK_OBJECT (mw), "size-allocate",
-        GTK_SIGNAL_FUNC (on_size_allocate), mw);
-    gtk_signal_connect (
-        GTK_OBJECT (mw), "delete-event",
-        GTK_SIGNAL_FUNC (on_delete_event), mw);
-    gtk_signal_connect (
-        GTK_OBJECT (mw->priv->paned),
-        "button_press_event", GTK_SIGNAL_FUNC (on_slide_button_press), mw);
-    g_signal_connect (
-        mw, "window-state-event",
-    GTK_SIGNAL_FUNC (on_window_state_event), NULL);
+    gtk_signal_connect (GTK_OBJECT (GNOME_CMD_FILE_SELECTOR (mw->priv->file_selector[LEFT])->list),
+                        "resize_column", GTK_SIGNAL_FUNC (on_fs_list_resize_column),
+                        GNOME_CMD_FILE_SELECTOR (mw->priv->file_selector[RIGHT])->list);
+    gtk_signal_connect (GTK_OBJECT (GNOME_CMD_FILE_SELECTOR (mw->priv->file_selector[RIGHT])->list),
+                        "resize_column", GTK_SIGNAL_FUNC (on_fs_list_resize_column),
+                        GNOME_CMD_FILE_SELECTOR (mw->priv->file_selector[LEFT])->list);
+    gtk_signal_connect (GTK_OBJECT (GNOME_CMD_FILE_SELECTOR (mw->priv->file_selector[LEFT])->list),
+                        "button_press_event", GTK_SIGNAL_FUNC (on_left_fs_select), mw);
+    gtk_signal_connect (GTK_OBJECT (GNOME_CMD_FILE_SELECTOR (mw->priv->file_selector[RIGHT])->list),
+                        "button_press_event", GTK_SIGNAL_FUNC (on_right_fs_select), mw);
+    gtk_signal_connect (GTK_OBJECT (mw), "size-allocate",
+                        GTK_SIGNAL_FUNC (on_size_allocate), mw);
+    gtk_signal_connect (GTK_OBJECT (mw), "delete-event",
+                        GTK_SIGNAL_FUNC (on_delete_event), mw);
+    gtk_signal_connect (GTK_OBJECT (mw->priv->paned),
+                        "button_press_event", GTK_SIGNAL_FUNC (on_slide_button_press), mw);
+    g_signal_connect (mw, "window-state-event", GTK_SIGNAL_FUNC (on_window_state_event), NULL);
 
     gnome_cmd_file_selector_update_connections (gnome_cmd_main_win_get_fs (mw, LEFT));
     gnome_cmd_file_selector_update_connections (gnome_cmd_main_win_get_fs (mw, RIGHT));
 
-    gnome_cmd_file_selector_set_connection (
-        gnome_cmd_main_win_get_fs (mw, LEFT),
-        gnome_cmd_con_list_get_home (gnome_cmd_data_get_con_list ()), NULL);
-    gnome_cmd_file_selector_set_connection (
-        gnome_cmd_main_win_get_fs (mw, RIGHT),
-        gnome_cmd_con_list_get_home (gnome_cmd_data_get_con_list ()), NULL);
+    gnome_cmd_file_selector_set_connection (gnome_cmd_main_win_get_fs (mw, LEFT), get_home_con ());
+    gnome_cmd_file_selector_set_connection (gnome_cmd_main_win_get_fs (mw, RIGHT), get_home_con ());
 
     gnome_cmd_file_selector_goto_directory (gnome_cmd_main_win_get_fs (mw, LEFT),
                                             start_dir_left ? start_dir_left : gnome_cmd_data_get_start_dir (LEFT));
@@ -921,8 +852,7 @@ init (GnomeCmdMainWin *mw)
 }
 
 
-GtkType
-gnome_cmd_main_win_get_type         (void)
+GtkType gnome_cmd_main_win_get_type (void)
 {
     static GtkType mw_type = 0;
 
@@ -947,8 +877,7 @@ gnome_cmd_main_win_get_type         (void)
 }
 
 
-GtkWidget *
-gnome_cmd_main_win_new              ()
+GtkWidget *gnome_cmd_main_win_new ()
 {
     GnomeCmdMainWin *mw = (GnomeCmdMainWin *) gtk_type_new (gnome_cmd_main_win_get_type ());
 
@@ -964,11 +893,11 @@ GnomeCmdFileSelector *gnome_cmd_main_win_get_fs (GnomeCmdMainWin *mw, FileSelect
     {
         case LEFT:
         case RIGHT:
-            return mw->priv->file_selector[fs] ? 
+            return mw->priv->file_selector[fs] ?
                    GNOME_CMD_FILE_SELECTOR (mw->priv->file_selector[fs]) : NULL;
-        
+
         case ACTIVE:
-            return mw->priv->file_selector[mw->priv->current_fs] ? 
+            return mw->priv->file_selector[mw->priv->current_fs] ?
                    GNOME_CMD_FILE_SELECTOR (mw->priv->file_selector[mw->priv->current_fs]) : NULL;
 
         case INACTIVE:
@@ -981,8 +910,7 @@ GnomeCmdFileSelector *gnome_cmd_main_win_get_fs (GnomeCmdMainWin *mw, FileSelect
 }
 
 
-void
-gnome_cmd_main_win_update_style          (GnomeCmdMainWin *mw)
+void gnome_cmd_main_win_update_style (GnomeCmdMainWin *mw)
 {
     g_return_if_fail (mw != NULL);
     g_return_if_fail (mw->priv != NULL);
@@ -997,18 +925,17 @@ gnome_cmd_main_win_update_style          (GnomeCmdMainWin *mw)
 }
 
 
-void
-gnome_cmd_main_win_focus_cmdline         (GnomeCmdMainWin *mw)
+void gnome_cmd_main_win_focus_cmdline (GnomeCmdMainWin *mw)
 {
-    if (gnome_cmd_data_get_cmdline_visibility ()) {
+    if (gnome_cmd_data_get_cmdline_visibility ())
+    {
         gnome_cmd_cmdline_focus (GNOME_CMD_CMDLINE (mw->priv->cmdline));
         mw->priv->focused_widget = mw->priv->cmdline;
     }
 }
 
 
-void
-gnome_cmd_main_win_focus_file_lists      (GnomeCmdMainWin *mw)
+void gnome_cmd_main_win_focus_file_lists (GnomeCmdMainWin *mw)
 {
     gnome_cmd_file_selector_set_active (gnome_cmd_main_win_get_fs (mw, ACTIVE), TRUE);
     gnome_cmd_file_selector_set_active (gnome_cmd_main_win_get_fs (mw, INACTIVE), FALSE);
@@ -1017,17 +944,14 @@ gnome_cmd_main_win_focus_file_lists      (GnomeCmdMainWin *mw)
 }
 
 
-void
-gnome_cmd_main_win_refocus               (GnomeCmdMainWin *mw)
+void gnome_cmd_main_win_refocus (GnomeCmdMainWin *mw)
 {
     if (mw->priv->focused_widget)
         gtk_widget_grab_focus (mw->priv->focused_widget);
 }
 
 
-gboolean
-gnome_cmd_main_win_keypressed            (GnomeCmdMainWin *mw,
-                                          GdkEventKey *event)
+gboolean gnome_cmd_main_win_keypressed (GnomeCmdMainWin *mw, GdkEventKey *event)
 {
     if (state_is_alt (event->state))
     {
@@ -1066,11 +990,6 @@ gnome_cmd_main_win_keypressed            (GnomeCmdMainWin *mw,
                 gnome_cmd_main_win_update_style (main_win);
                 gnome_cmd_data_save ();
                 return TRUE;
-
-            case GDK_equal:
-            case GDK_plus:
-                gnome_cmd_main_win_set_equal_panes (mw);
-                return TRUE;
         }
     }
     else if (state_is_ctrl (event->state))
@@ -1105,15 +1024,6 @@ gnome_cmd_main_win_keypressed            (GnomeCmdMainWin *mw,
             case GDK_q:
                 gtk_widget_destroy (GTK_WIDGET (main_win));
                 return TRUE;
-
-           case GDK_backslash:
-               gnome_cmd_file_selector_goto_directory (gnome_cmd_main_win_get_fs (main_win, ACTIVE), "/");
-               return TRUE;
-
-           case GDK_quoteleft:
-           case GDK_asciitilde:
-               gnome_cmd_file_selector_goto_directory (gnome_cmd_main_win_get_fs (main_win, ACTIVE), "~");
-               return TRUE;
         }
     }
     else if (state_is_alt_shift (event->state))
@@ -1125,23 +1035,12 @@ gnome_cmd_main_win_keypressed            (GnomeCmdMainWin *mw,
                 plugin_manager_show ();
                 break;
 
-            case GDK_S:
-            case GDK_s:
-                gnome_cmd_dir_pool_show_state (
-                    gnome_cmd_con_get_dir_pool (
-                        gnome_cmd_file_selector_get_connection (
-                            gnome_cmd_main_win_get_fs (mw, ACTIVE))));
-                break;
-
             case GDK_f:
             case GDK_F:
             {
-                GnomeCmdConFtp *con = GNOME_CMD_CON_FTP (gnome_cmd_con_list_get_all_ftp (
-                    gnome_cmd_data_get_con_list ())->data);
+                GnomeCmdConFtp *con = GNOME_CMD_CON_FTP (gnome_cmd_con_list_get_all_ftp (gnome_cmd_con_list_get ())->data);
 
-                gnome_cmd_file_selector_set_connection (
-                    gnome_cmd_main_win_get_fs (main_win, ACTIVE),
-                    GNOME_CMD_CON (con), NULL);
+                gnome_cmd_file_selector_set_connection (gnome_cmd_main_win_get_fs (main_win, ACTIVE), GNOME_CMD_CON (con));
             }
             break;
         }
@@ -1151,7 +1050,7 @@ gnome_cmd_main_win_keypressed            (GnomeCmdMainWin *mw,
             switch (event->keyval)
             {
                 case GDK_Tab:
-                    // hack to avoid the deafult handling of the tab-key
+                    // hack to avoid the default handling of the tab-key
                     clear_event_key (event);
                     gnome_cmd_main_win_switch_fs (mw, gnome_cmd_main_win_get_fs (mw, INACTIVE));
                     return TRUE;
@@ -1204,8 +1103,7 @@ gnome_cmd_main_win_keypressed            (GnomeCmdMainWin *mw,
 }
 
 
-void
-gnome_cmd_main_win_switch_fs (GnomeCmdMainWin *mw, GnomeCmdFileSelector *fs)
+void gnome_cmd_main_win_switch_fs (GnomeCmdMainWin *mw, GnomeCmdFileSelector *fs)
 {
     g_return_if_fail (GNOME_CMD_IS_MAIN_WIN (mw));
     g_return_if_fail (GNOME_CMD_IS_FILE_SELECTOR (fs));
@@ -1219,8 +1117,7 @@ gboolean gnome_cmd_main_win_is_fs_active (GnomeCmdMainWin *mw, FileSelectorID fs
     return mw->priv->current_fs == fs;
 }
 
-static void
-gnome_cmd_main_win_real_switch_fs (GnomeCmdMainWin *mw, GnomeCmdFileSelector *fs)
+static void gnome_cmd_main_win_real_switch_fs (GnomeCmdMainWin *mw, GnomeCmdFileSelector *fs)
 {
     g_return_if_fail (GNOME_CMD_IS_MAIN_WIN (mw));
     g_return_if_fail (GNOME_CMD_IS_FILE_SELECTOR (fs));
@@ -1237,8 +1134,7 @@ gnome_cmd_main_win_real_switch_fs (GnomeCmdMainWin *mw, GnomeCmdFileSelector *fs
 }
 
 
-GnomeCmdCmdline*
-gnome_cmd_main_win_get_cmdline           (GnomeCmdMainWin *mw)
+GnomeCmdCmdline *gnome_cmd_main_win_get_cmdline (GnomeCmdMainWin *mw)
 {
     g_return_val_if_fail (GNOME_CMD_IS_MAIN_WIN (mw), NULL);
 
@@ -1246,8 +1142,7 @@ gnome_cmd_main_win_get_cmdline           (GnomeCmdMainWin *mw)
 }
 
 
-void
-gnome_cmd_main_win_update_bookmarks (GnomeCmdMainWin *mw)
+void gnome_cmd_main_win_update_bookmarks (GnomeCmdMainWin *mw)
 {
     g_return_if_fail (GNOME_CMD_IS_MAIN_WIN (mw));
 
@@ -1255,8 +1150,7 @@ gnome_cmd_main_win_update_bookmarks (GnomeCmdMainWin *mw)
 }
 
 
-void
-gnome_cmd_main_win_update_toolbar_visibility (GnomeCmdMainWin *mw)
+void gnome_cmd_main_win_update_toolbar_visibility (GnomeCmdMainWin *mw)
 {
     g_return_if_fail (GNOME_CMD_IS_MAIN_WIN (mw));
 
@@ -1276,8 +1170,10 @@ gnome_cmd_main_win_update_toolbar_visibility (GnomeCmdMainWin *mw)
         GNOMEUIINFO_ITEM_STOCK(NULL, _("Delete"), file_delete, GTK_STOCK_DELETE),
         GNOMEUIINFO_SEPARATOR,
         GNOMEUIINFO_ITEM_STOCK(NULL, _("Edit (SHIFT for new document)"), file_edit, GTK_STOCK_EDIT),
+        GNOMEUIINFO_ITEM_STOCK(NULL, _("Send files"), file_sendto, GNOME_STOCK_MAIL_SND),
+        GNOMEUIINFO_ITEM_FILENAME(NULL, _("Open terminal"), command_open_terminal, PACKAGE_NAME G_DIR_SEPARATOR_S "terminal.svg"),
         GNOMEUIINFO_SEPARATOR,
-        GNOMEUIINFO_ITEM_STOCK(NULL, _("FTP Connect"), connections_ftp_connect, GTK_STOCK_CONNECT),
+        GNOMEUIINFO_ITEM_STOCK(NULL, _("Remote Server"), connections_open, GTK_STOCK_CONNECT),
         GNOMEUIINFO_ITEM_NONE(NULL, _("Drop connection"), connections_close_current),
         GNOMEUIINFO_END
     };
@@ -1304,8 +1200,7 @@ gnome_cmd_main_win_update_toolbar_visibility (GnomeCmdMainWin *mw)
 }
 
 
-void
-gnome_cmd_main_win_update_buttonbar_visibility (GnomeCmdMainWin *mw)
+void gnome_cmd_main_win_update_buttonbar_visibility (GnomeCmdMainWin *mw)
 {
     g_return_if_fail (GNOME_CMD_IS_MAIN_WIN (mw));
 
@@ -1327,8 +1222,7 @@ gnome_cmd_main_win_update_buttonbar_visibility (GnomeCmdMainWin *mw)
 }
 
 
-void
-gnome_cmd_main_win_update_cmdline_visibility (GnomeCmdMainWin *mw)
+void gnome_cmd_main_win_update_cmdline_visibility (GnomeCmdMainWin *mw)
 {
     g_return_if_fail (GNOME_CMD_IS_MAIN_WIN (mw));
 
@@ -1348,7 +1242,8 @@ gnome_cmd_main_win_update_cmdline_visibility (GnomeCmdMainWin *mw)
         gtk_box_reorder_child (GTK_BOX (mw->priv->vbox), mw->priv->cmdline_sep, pos);
         gtk_box_reorder_child (GTK_BOX (mw->priv->vbox), mw->priv->cmdline, pos+1);
     }
-    else {
+    else
+    {
         if (mw->priv->cmdline)
             gtk_widget_destroy (mw->priv->cmdline);
         if (mw->priv->cmdline_sep)
@@ -1359,8 +1254,7 @@ gnome_cmd_main_win_update_cmdline_visibility (GnomeCmdMainWin *mw)
 }
 
 
-void
-gnome_cmd_main_win_update_connections (GnomeCmdMainWin *mw)
+void gnome_cmd_main_win_update_connections (GnomeCmdMainWin *mw)
 {
     g_return_if_fail (GNOME_CMD_IS_MAIN_WIN (mw));
 
@@ -1370,8 +1264,7 @@ gnome_cmd_main_win_update_connections (GnomeCmdMainWin *mw)
 }
 
 
-void
-gnome_cmd_main_win_update_list_orientation (GnomeCmdMainWin *mw)
+void gnome_cmd_main_win_update_list_orientation (GnomeCmdMainWin *mw)
 {
     gint pos = 2;
 
@@ -1407,8 +1300,7 @@ gnome_cmd_main_win_update_list_orientation (GnomeCmdMainWin *mw)
 }
 
 
-void
-gnome_cmd_main_win_add_plugin_menu (GnomeCmdMainWin *mw, PluginData *data)
+void gnome_cmd_main_win_add_plugin_menu (GnomeCmdMainWin *mw, PluginData *data)
 {
     g_return_if_fail (GNOME_CMD_IS_MAIN_WIN (mw));
 
@@ -1416,8 +1308,7 @@ gnome_cmd_main_win_add_plugin_menu (GnomeCmdMainWin *mw, PluginData *data)
 }
 
 
-GnomeCmdState *
-gnome_cmd_main_win_get_state (GnomeCmdMainWin *mw)
+GnomeCmdState *gnome_cmd_main_win_get_state (GnomeCmdMainWin *mw)
 {
     g_return_val_if_fail (GNOME_CMD_IS_MAIN_WIN (mw), NULL);
 
@@ -1438,8 +1329,7 @@ gnome_cmd_main_win_get_state (GnomeCmdMainWin *mw)
 }
 
 
-void
-gnome_cmd_main_win_set_cap_state (GnomeCmdMainWin *mw, gboolean state)
+void gnome_cmd_main_win_set_cap_state (GnomeCmdMainWin *mw, gboolean state)
 {
     g_return_if_fail (GNOME_CMD_IS_MAIN_WIN (mw));
 
@@ -1447,8 +1337,7 @@ gnome_cmd_main_win_set_cap_state (GnomeCmdMainWin *mw, gboolean state)
 }
 
 
-void
-gnome_cmd_main_win_set_equal_panes (GnomeCmdMainWin *mw)
+void gnome_cmd_main_win_set_equal_panes (GnomeCmdMainWin *mw)
 {
     slide_set_50_50 (NULL, NULL);
 }
