@@ -19,8 +19,6 @@
 #ifndef __GNOME_CMD_OPTIONS_DIALOG_H__
 #define __GNOME_CMD_OPTIONS_DIALOG_H__
 
-G_BEGIN_DECLS
-
 #define GNOME_CMD_OPTIONS_DIALOG(obj) \
     GTK_CHECK_CAST (obj, gnome_cmd_options_dialog_get_type (), GnomeCmdOptionsDialog)
 #define GNOME_CMD_OPTIONS_DIALOG_CLASS(klass) \
@@ -41,6 +39,7 @@ typedef enum
     GNOME_CMD_OPTIONS_DIALOG_TAB_LAYOUT,
     GNOME_CMD_OPTIONS_DIALOG_TAB_CONFIRMATION,
     GNOME_CMD_OPTIONS_DIALOG_TAB_FILTERS,
+    GNOME_CMD_OPTIONS_DIALOG_TAB_NETWORK,
     GNOME_CMD_OPTIONS_DIALOG_TAB_PROGRAMS,
     GNOME_CMD_OPTIONS_DIALOG_TAB_DEVICES
 } GnomeCmdOptionsDialogTab;
@@ -72,6 +71,4 @@ void
 gnome_cmd_options_dialog_set_tab             (GnomeCmdOptionsDialog *dialog,
                                               GnomeCmdOptionsDialogTab tab);
 
-G_END_DECLS
-
 #endif // __GNOME_CMD_OPTIONS_DIALOG_H__
