@@ -35,11 +35,8 @@ using namespace std;
 static GnomeCmdDialogClass *parent_class = NULL;
 
 
-static void
-on_ok (GtkButton *button, GnomeCmdPrepareXferDialog *dialog)
+static void on_ok (GtkButton *button, GnomeCmdPrepareXferDialog *dialog)
 {
-    GnomeVFSResult res;
-    GnomeVFSFileType type;
     GnomeCmdDir *dest_dir;
     gchar *dest_fn = NULL;
     gchar *dest_path;
@@ -62,14 +59,16 @@ on_ok (GtkButton *button, GnomeCmdPrepareXferDialog *dialog)
         dest_path = user_path;
     else
     {
-        gchar *tmp = gnome_cmd_file_get_path (GNOME_CMD_FILE (
-            gnome_cmd_file_selector_get_directory (dialog->src_fs)));
+        gchar *tmp = gnome_cmd_file_get_path (GNOME_CMD_FILE (gnome_cmd_file_selector_get_directory (dialog->src_fs)));
         dest_path = g_build_path (G_DIR_SEPARATOR_S, tmp, user_path, NULL);
         g_free (user_path);
         g_free (tmp);
     }
 
     // Check if something exists at the given path and find out what it is
+    GnomeVFSFileType type;
+    GnomeVFSResult   res;
+
     res = gnome_cmd_con_get_path_target_type (con, dest_path, &type);
 
     if (res != GNOME_VFS_OK && res != GNOME_VFS_ERROR_NOT_FOUND)
@@ -82,8 +81,7 @@ on_ok (GtkButton *button, GnomeCmdPrepareXferDialog *dialog)
         if (res == GNOME_VFS_OK && type == GNOME_VFS_FILE_TYPE_DIRECTORY)
         {
             // There exists a directory, copy into it using the original filename
-            dest_dir = gnome_cmd_dir_new (
-                con, gnome_cmd_con_create_path (con, dest_path));
+            dest_dir = gnome_cmd_dir_new (con, gnome_cmd_con_create_path (con, dest_path));
             dest_fn = g_strdup (gnome_cmd_file_get_name (finfo));
         }
         else
@@ -116,15 +114,13 @@ on_ok (GtkButton *button, GnomeCmdPrepareXferDialog *dialog)
             else
             {
                 // Nothing exists, ask the user if a new directory might be suitable in the path that he specified
-                gchar *msg = g_strdup_printf (
-                    _("The directory '%s' doesn't exist, do you want to create it?"),
-                    g_basename (parent_dir));
-                gint choise = run_simple_dialog (
-                    GTK_WIDGET (dialog), TRUE, GTK_MESSAGE_QUESTION, msg, "",
-                    -1, _("No"), _("Yes"), NULL);
+                gchar *msg = g_strdup_printf (_("The directory '%s' doesn't exist, do you want to create it?"),
+                                              g_basename (parent_dir));
+                gint choice = run_simple_dialog (GTK_WIDGET (dialog), TRUE, GTK_MESSAGE_QUESTION, msg, "",
+                                                 -1, _("No"), _("Yes"), NULL);
                 g_free (msg);
 
-                if (choise == 1)
+                if (choice == 1)
                 {
                     GnomeVFSResult mkdir_result = gnome_cmd_con_mkdir (con, parent_dir);
                     if (mkdir_result != GNOME_VFS_OK)
@@ -136,8 +132,7 @@ on_ok (GtkButton *button, GnomeCmdPrepareXferDialog *dialog)
                 else
                     goto bailout;
 
-                dest_dir = gnome_cmd_dir_new (
-                    con, gnome_cmd_con_create_path (con, parent_dir));
+                dest_dir = gnome_cmd_dir_new (con, gnome_cmd_con_create_path (con, parent_dir));
                 g_free (parent_dir);
                 dest_fn = g_strdup (g_basename (dest_path));
             }
@@ -157,20 +152,18 @@ on_ok (GtkButton *button, GnomeCmdPrepareXferDialog *dialog)
         }
         else
         {
-            /* Nothing exists, ask the user if a new directory might be suitable
-               in the path that he specified */
-            gchar *msg = g_strdup_printf (
-                _("The directory '%s' doesn't exist, do you want to create it?"),
-                g_basename (dest_path));
+            // Nothing exists, ask the user if a new directory might be suitable in the path that he specified
+            gchar *msg = g_strdup_printf (_("The directory '%s' doesn't exist, do you want to create it?"),
+                                          g_basename (dest_path));
             GtkWidget *dialog = gtk_message_dialog_new (GTK_WINDOW (main_win),
                                                         (GtkDialogFlags) 0,
                                                         GTK_MESSAGE_QUESTION,
                                                         GTK_BUTTONS_OK_CANCEL,
                                                         msg);
-            gint choise = gtk_dialog_run (GTK_DIALOG (dialog));
+            gint choice = gtk_dialog_run (GTK_DIALOG (dialog));
             g_free (msg);
 
-            if (choise == GTK_RESPONSE_OK)
+            if (choice == GTK_RESPONSE_OK)
             {
                 GnomeVFSResult mkdir_result = gnome_cmd_con_mkdir (con, dest_path);
                 if (mkdir_result != GNOME_VFS_OK)
@@ -190,11 +183,9 @@ on_ok (GtkButton *button, GnomeCmdPrepareXferDialog *dialog)
         goto bailout;
 
     if (g_list_length (dialog->src_files) == 1)
-        DEBUG ('x', "Im now going to xfer the file file '%s' to '%s'\n",
-                dest_fn, gnome_cmd_file_get_real_path (GNOME_CMD_FILE (dest_dir)));
+        DEBUG ('x', "Im now going to xfer the file file '%s' to '%s'\n", dest_fn, gnome_cmd_file_get_real_path (GNOME_CMD_FILE (dest_dir)));
     else
-        DEBUG ('x', "Im now going to xfer %d files to '%s'\n",
-                g_list_length (dialog->src_files), gnome_cmd_file_get_real_path (GNOME_CMD_FILE (dest_dir)));
+        DEBUG ('x', "Im now going to xfer %d files to '%s'\n", g_list_length (dialog->src_files), gnome_cmd_file_get_real_path (GNOME_CMD_FILE (dest_dir)));
 
 
     gnome_cmd_dir_ref (dest_dir);
@@ -212,8 +203,7 @@ bailout:
 }
 
 
-static void
-on_cancel (GtkButton *button, gpointer user_data)
+static void on_cancel (GtkButton *button, gpointer user_data)
 {
     GnomeCmdPrepareXferDialog *dialog = GNOME_CMD_PREPARE_XFER_DIALOG (user_data);
 
@@ -221,10 +211,7 @@ on_cancel (GtkButton *button, gpointer user_data)
 }
 
 
-static gboolean
-on_dest_dir_entry_keypressed (GtkEntry *entry,
-                              GdkEventKey *event,
-                              GnomeCmdPrepareXferDialog *dialog)
+static gboolean on_dest_dir_entry_keypressed (GtkEntry *entry, GdkEventKey *event, GnomeCmdPrepareXferDialog *dialog)
 {
     if (event->keyval == GDK_Return)
     {
@@ -240,8 +227,7 @@ on_dest_dir_entry_keypressed (GtkEntry *entry,
  * Gtk class implementation
  *******************************/
 
-static void
-destroy (GtkObject *object)
+static void destroy (GtkObject *object)
 {
     GnomeCmdPrepareXferDialog *dialog = GNOME_CMD_PREPARE_XFER_DIALOG (object);
 
@@ -252,16 +238,14 @@ destroy (GtkObject *object)
 }
 
 
-static void
-map (GtkWidget *widget)
+static void map (GtkWidget *widget)
 {
     if (GTK_WIDGET_CLASS (parent_class)->map != NULL)
         GTK_WIDGET_CLASS (parent_class)->map (widget);
 }
 
 
-static void
-class_init (GnomeCmdPrepareXferDialogClass *klass)
+static void class_init (GnomeCmdPrepareXferDialogClass *klass)
 {
     GtkObjectClass *object_class = GTK_OBJECT_CLASS (klass);
     GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
@@ -273,8 +257,7 @@ class_init (GnomeCmdPrepareXferDialogClass *klass)
 }
 
 
-static void
-init (GnomeCmdPrepareXferDialog *dialog)
+static void init (GnomeCmdPrepareXferDialog *dialog)
 {
     GtkWidget *dest_dir_vbox;
     GtkWidget *dest_dir_fileentry;
@@ -309,15 +292,11 @@ init (GnomeCmdPrepareXferDialog *dialog)
 
 
     // buttons
-    dialog->cancel_button = gnome_cmd_dialog_add_button (
-        GNOME_CMD_DIALOG (dialog), GNOME_STOCK_BUTTON_CANCEL, NULL, NULL);
-    dialog->ok_button = gnome_cmd_dialog_add_button (
-        GNOME_CMD_DIALOG (dialog), GNOME_STOCK_BUTTON_OK, NULL, NULL);
+    dialog->cancel_button = gnome_cmd_dialog_add_button (GNOME_CMD_DIALOG (dialog), GNOME_STOCK_BUTTON_CANCEL, NULL, NULL);
+    dialog->ok_button = gnome_cmd_dialog_add_button (GNOME_CMD_DIALOG (dialog), GNOME_STOCK_BUTTON_OK, NULL, NULL);
 
-    gtk_signal_connect_after (GTK_OBJECT (dialog->cancel_button), "clicked",
-                              GTK_SIGNAL_FUNC (on_cancel), dialog);
-    gtk_signal_connect_after (GTK_OBJECT (dialog->ok_button), "clicked",
-                              GTK_SIGNAL_FUNC (on_ok), dialog);
+    gtk_signal_connect_after (GTK_OBJECT (dialog->cancel_button), "clicked", GTK_SIGNAL_FUNC (on_cancel), dialog);
+    gtk_signal_connect_after (GTK_OBJECT (dialog->ok_button), "clicked", GTK_SIGNAL_FUNC (on_ok), dialog);
 
     gtk_widget_set_size_request (GTK_WIDGET (dialog), 500, -1);
 }
@@ -327,8 +306,7 @@ init (GnomeCmdPrepareXferDialog *dialog)
  * Public functions
  ***********************************/
 
-GtkType
-gnome_cmd_prepare_xfer_dialog_get_type         (void)
+GtkType gnome_cmd_prepare_xfer_dialog_get_type (void)
 {
     static GtkType dlg_type = 0;
 
@@ -352,8 +330,7 @@ gnome_cmd_prepare_xfer_dialog_get_type         (void)
 }
 
 
-static gboolean
-path_points_at_directory (GnomeCmdFileSelector *to, const gchar *dest_path)
+inline gboolean path_points_at_directory (GnomeCmdFileSelector *to, const gchar *dest_path)
 {
     GnomeVFSFileType type;
 
@@ -364,9 +341,7 @@ path_points_at_directory (GnomeCmdFileSelector *to, const gchar *dest_path)
 }
 
 
-GtkWidget *
-gnome_cmd_prepare_xfer_dialog_new (GnomeCmdFileSelector *from,
-                                   GnomeCmdFileSelector *to)
+GtkWidget *gnome_cmd_prepare_xfer_dialog_new (GnomeCmdFileSelector *from, GnomeCmdFileSelector *to)
 {
     gchar *dest_str;
     GnomeCmdPrepareXferDialog *dialog = (GnomeCmdPrepareXferDialog *) gtk_type_new (gnome_cmd_prepare_xfer_dialog_get_type ());
