@@ -22,9 +22,8 @@
 
 #include <gmodule.h>
 
-G_BEGIN_DECLS
-
-typedef struct {
+typedef struct
+{
     gboolean active;
     gboolean loaded;
     gboolean autoload;
@@ -42,6 +41,4 @@ void plugin_manager_shutdown (void);
 GList *plugin_manager_get_all (void);
 void plugin_manager_show (void);
 
-G_END_DECLS
-
 #endif // __PLUGIN_MANAGER_H__
