@@ -20,27 +20,35 @@
 #ifndef __GNOME_CMD_TAGS_H__
 #define __GNOME_CMD_TAGS_H__
 
-#include <config.h>
+#include <string>
+#include <map>
+#include <set>
+#include <sstream>
 
 #include "gnome-cmd-file.h"
+#include "utils.h"
 
-G_BEGIN_DECLS
-
-typedef enum {
-    TAG_FILE  = -1,
-    TAG_CHM   = 1 << 6,
-    TAG_EXIF  = 1 << 7,
-    TAG_IPTC  = 1 << 8,
-    TAG_ICC   = 1 << 9,
-    TAG_ID3   = 1 << 10,
-    TAG_RPM   = 1 << 11,
-    TAG_AUDIO = TAG_ID3+1,
-    TAG_DOC   = TAG_CHM+1,
-    TAG_IMAGE = TAG_EXIF | TAG_IPTC | TAG_ICC
+typedef enum
+{
+    TAG_NONE_CLASS  = 0,
+    TAG_FILE        = -1,
+    TAG_CHM         = 1 << 6,
+    TAG_EXIF        = 1 << 7,
+    TAG_IPTC        = 1 << 8,
+    TAG_ICC         = 1 << 9,
+    TAG_APE         = 1 << 10,
+    TAG_FLAC        = 1 << 11,
+    TAG_ID3         = 1 << 12,
+    TAG_VORBIS      = 1 << 13,
+    TAG_RPM         = 1 << 14,
+    TAG_AUDIO       = TAG_APE | TAG_FLAC | TAG_ID3 | TAG_VORBIS,
+    TAG_DOC         = TAG_CHM+1,
+    TAG_IMAGE       = TAG_EXIF | TAG_IPTC | TAG_ICC
 } GnomeCmdTagClass;
 
 
-typedef enum {
+typedef enum
+{
     TAG_NONE,
     TAG_AUDIO_ALBUMARTIST,                  // artist of the album
     TAG_AUDIO_ALBUMGAIN,                    // gain adjustment of album
@@ -53,33 +61,80 @@ typedef enum {
     TAG_AUDIO_CODECVERSION,                 // codec version
     TAG_AUDIO_CODEC,                        // codec encoding description
     TAG_AUDIO_COMMENT,                      // comments on the track
+    TAG_AUDIO_COPYRIGHT,                    // copyright message
     TAG_AUDIO_COVERALBUMTHUMBNAILPATH,      // file path to thumbnail image of the cover album
     TAG_AUDIO_DISCNO,                       // specifies which disc the track is on
     TAG_AUDIO_DURATION,                     // duration of track in seconds
+    TAG_AUDIO_DURATIONMMSS,                 // duration of track in MM:SS
     TAG_AUDIO_GENRE,                        // type of music classification for the track as defined in ID3 spec
     TAG_AUDIO_ISNEW,                        // set to "1" if track is new to the user (default "0")
+    TAG_AUDIO_ISRC,                         // ISRC (international standard recording code)
     TAG_AUDIO_LASTPLAY,                     // when track was last played
     TAG_AUDIO_LYRICS,                       // lyrics of the track
     TAG_AUDIO_MBALBUMARTISTID,              // musicBrainz album artist ID in UUID format
     TAG_AUDIO_MBALBUMID,                    // musicBrainz album ID in UUID format
     TAG_AUDIO_MBARTISTID,                   // musicBrainz artist ID in UUID format
     TAG_AUDIO_MBTRACKID,                    // musicBrainz track ID in UUID format
+    TAG_AUDIO_MPEG_CHANNELMODE,             // MPEG channel mode
+    TAG_AUDIO_MPEG_COPYRIGHTED,             // "1" if the copyrighted bit is set
+    TAG_AUDIO_MPEG_LAYER,                   // MPEG layer
+    TAG_AUDIO_MPEG_ORIGINAL,                // "1" if the "original" bit is set
+    TAG_AUDIO_MPEG_VERSION,                 // MPEG version
     TAG_AUDIO_PERFORMER,                    // name of the performer/conductor of the music
     TAG_AUDIO_PLAYCOUNT,                    // number of times the track has been played
     TAG_AUDIO_RELEASEDATE,                  // date track was released
-    TAG_AUDIO_SAMPLERATE,                   // samplerate in Hz
+    TAG_AUDIO_SAMPLERATE,                   // sample rate in Hz
     TAG_AUDIO_TITLE,                        // title of the track
     TAG_AUDIO_TRACKGAIN,                    // gain adjustment of track
     TAG_AUDIO_TRACKNO,                      // position of track on the album
     TAG_AUDIO_TRACKPEAKGAIN,                // peak gain adjustment of track
+    TAG_AUDIO_YEAR,                         // year
     TAG_DOC_AUTHOR,                         // name of the author
+    TAG_DOC_BYTECOUNT,                      // number of bytes in the document
+    TAG_DOC_CASESENSITIVE,                  // case sensitive
+    TAG_DOC_CATEGORY,                       // category
+    TAG_DOC_CELLCOUNT,                      // number of cells in the spreadsheet document
+    TAG_DOC_CHARACTERCOUNT,                 // number of characters in the document
+    TAG_DOC_CODEPAGE,                       // the MS codepage to encode strings for metadata
     TAG_DOC_COMMENTS,                       // user definable free text
-    TAG_DOC_CREATED,                        // datetime document was originally
-    TAG_DOC_KEYWORDS,                       // string of keywords
-    TAG_DOC_PAGECOUNT,                      // no. of pages in document
+    TAG_DOC_COMPANY,                        // organization that the <Doc.Creator> entity is associated with
+    TAG_DOC_CREATED,                        // datetime document was originally created
+    TAG_DOC_CREATOR,                        // an entity primarily responsible for making the content of the resource, typically a person, organization, or service
+    TAG_DOC_DATECREATED,                    // date associated with an event in the life cycle of the resource (creation/publication date)
+    TAG_DOC_DATEMODIFIED,                   // the last time the document was saved
+    TAG_DOC_DESCRIPTION,                    // an acccount of the content of the resource
+    TAG_DOC_DICTIONARY,                     // dictionary
+    TAG_DOC_EDITINGDURATION,                // the total time taken until the last modification
+    TAG_DOC_GENERATOR,                      // the application that generated this document
+    TAG_DOC_HIDDENSLIDECOUNT,               // number of hidden slides in the presentation document
+    TAG_DOC_IMAGECOUNT,                     // number of images in the document
+    TAG_DOC_INITIALCREATOR,                 // specifies the name of the person who created the document initially
+    TAG_DOC_KEYWORDS,                       // searchable, indexable keywords
+    TAG_DOC_LANGUAGE,                       // the locale language of the intellectual content of the resource
+    TAG_DOC_LASTPRINTED,                    // the last time this document was printed
+    TAG_DOC_LASTSAVEDBY,                    // the entity that made the last change to the document, typically a person, organization, or service
+    TAG_DOC_LINECOUNT,                      // number of lines in the document
+    TAG_DOC_LINKSDIRTY,                     // links dirty
+    TAG_DOC_LOCALESYSTEMDEFAULT,            // identifier representing the default system locale
+    TAG_DOC_MMCLIPCOUNT,                    // number of multimedia clips in the document
+    TAG_DOC_MANAGER,                        // name of the manager of <Doc.Creator> entity
+    TAG_DOC_NOTECOUNT,                      // number of "notes" in the document
+    TAG_DOC_OBJECTCOUNT,                    // number of objects (OLE and other graphics) in the document
+    TAG_DOC_PAGECOUNT,                      // number of pages in the document
+    TAG_DOC_PARAGRAPHCOUNT,                 // number of paragraphs in the document
+    TAG_DOC_PRESENTATIONFORMAT,             // type of presentation, like "On-screen Show", "SlideView", etc
+    TAG_DOC_PRINTDATE,                      // specifies the date and time when the document was last printed
+    TAG_DOC_PRINTEDBY,                      // specifies the name of the last person who printed the document
+    TAG_DOC_REVISIONCOUNT,                  // number of revision on the document
+    TAG_DOC_SCALE,                          // scale
+    TAG_DOC_SECURITY,                       // one of: "Password protected", "Read-only recommended", "Read-only enforced" or "Locked for annotations"
+    TAG_DOC_SLIDECOUNT,                     // number of slides in the presentation document
+    TAG_DOC_SPREADSHEETCOUNT,               // number of pages in the document
     TAG_DOC_SUBJECT,                        // document subject
-    TAG_DOC_TITLE,                          // title of document
-    TAG_DOC_WORDCOUNT,                      // total no. of chars in document
+    TAG_DOC_TABLECOUNT,                     // number of tables in the document
+    TAG_DOC_TEMPLATE,                       // the template file that is been used to generate this document
+    TAG_DOC_TITLE,                          // title of the document
+    TAG_DOC_WORDCOUNT,                      // number of words in the document
     TAG_EXIF_APERTUREVALUE,                 // lens aperture
     TAG_EXIF_ARTIST,                        // person who created the image
     TAG_EXIF_BATTERYLEVEL,                  // battery level
@@ -199,10 +254,8 @@ typedef enum {
     TAG_FILE_ACCESSED,                      // last access datetime
     TAG_FILE_CONTENT,                       // file's contents filtered as plain text (IE as stored by the indexer)
     TAG_FILE_DESCRIPTION,                   // editable free text/notes
-    TAG_FILE_FORMAT,                        // mime type of the file or if a directory it should contain value "Folder"
-    TAG_FILE_ICONPATH,                      // editable file uri for a custom icon for the file
+    TAG_FILE_FORMAT,                        // MIME type of the file or if a directory it should contain value "Folder"
     TAG_FILE_KEYWORDS,                      // editable array of keywords
-    TAG_FILE_LARGETHUMBNAILPATH,            // editable file uri for a larger thumbnail of the file suitable for previews
     TAG_FILE_LINK,                          // URI of link target
     TAG_FILE_MODIFIED,                      // last modified datetime
     TAG_FILE_NAME,                          // file name excluding path but including the file extension
@@ -211,19 +264,13 @@ typedef enum {
     TAG_FILE_PUBLISHER,                     // editable DC type for the name of the publisher of the file (EG dc:publisher field in RSS feed)
     TAG_FILE_RANK,                          // editable file rank for grading favourites. Value should be in the range 1..10
     TAG_FILE_SIZE,                          // size of the file in bytes or if a directory no. of items it contains
-    TAG_FILE_SMALLTHUMBNAILPATH,            // editable file uri for a small thumbnail of the file suitable for use in icon views
-    TAG_ID3_ALBUM,                          // album
     TAG_ID3_ALBUMSORTORDER,                 // album sort order
     TAG_ID3_AUDIOCRYPTO,                    // audio encryption
     TAG_ID3_AUDIOSEEKPOINT,                 // audio seek point index
     TAG_ID3_BAND,                           // band
-    TAG_ID3_BITRATE,                        // bitrate in kbps
     TAG_ID3_BPM,                            // BPM (beats per minute)
     TAG_ID3_BUFFERSIZE,                     // recommended buffer size
     TAG_ID3_CDID,                           // music CD identifier
-    TAG_ID3_CHANNELMODE,                    // channel mode
-    TAG_ID3_CHANNELS,                       // number of channels in the audio (2 = stereo)
-    TAG_ID3_COMMENT,                        // comments
     TAG_ID3_COMMERCIAL,                     // commercial frame
     TAG_ID3_COMPOSER,                       // composer
     TAG_ID3_CONDUCTOR,                      // conductor
@@ -232,8 +279,6 @@ typedef enum {
     TAG_ID3_COPYRIGHT,                      // copyright message
     TAG_ID3_CRYPTOREG,                      // encryption method registration
     TAG_ID3_DATE,                           // date
-    TAG_ID3_DURATION,                       // duration of track in seconds
-    TAG_ID3_DURATIONMMSS,                   // duration of track in MM:SS
     TAG_ID3_EMPHASIS,                       // emphasis
     TAG_ID3_ENCODEDBY,                      // encoded by
     TAG_ID3_ENCODERSETTINGS,                // software
@@ -245,22 +290,17 @@ typedef enum {
     TAG_ID3_FILETYPE,                       // file type
     TAG_ID3_FRAMES,                         // number of frames
     TAG_ID3_GENERALOBJECT,                  // general encapsulated object
-    TAG_ID3_GENRE,                          // type of music classification for the track as defined in ID3 spec
     TAG_ID3_GROUPINGREG,                    // group identification registration
     TAG_ID3_INITIALKEY,                     // initial key
     TAG_ID3_INVOLVEDPEOPLE,                 // involved people list
     TAG_ID3_INVOLVEDPEOPLE2,                // involved people list
-    TAG_ID3_ISRC,                           // ISRC (international standard recording code)
     TAG_ID3_LANGUAGE,                       // language(s)
-    TAG_ID3_LEADARTIST,                     // lead performer(s)
     TAG_ID3_LINKEDINFO,                     // linked information
     TAG_ID3_LYRICIST,                       // lyricist
     TAG_ID3_MEDIATYPE,                      // media type
     TAG_ID3_MIXARTIST,                      // interpreted, remixed, or otherwise modified by
     TAG_ID3_MOOD,                           // mood
-    TAG_ID3_MPEGLAYER,                      // MPEG layer
     TAG_ID3_MPEGLOOKUP,                     // MPEG location lookup table
-    TAG_ID3_MPEGVERSION,                    // MPEG version
     TAG_ID3_MUSICIANCREDITLIST,             // musician credits list
     TAG_ID3_NETRADIOOWNER,                  // internet radio station owner
     TAG_ID3_NETRADIOSTATION,                // internet radio station name
@@ -285,7 +325,6 @@ typedef enum {
     TAG_ID3_RECORDINGTIME,                  // recording time
     TAG_ID3_RELEASETIME,                    // release time
     TAG_ID3_REVERB,                         // reverb
-    TAG_ID3_SAMPLERATE,                     // sample rate in Hz
     TAG_ID3_SETSUBTITLE,                    // set subtitle
     TAG_ID3_SIGNATURE,                      // signature frame
     TAG_ID3_SIZE,                           // size
@@ -296,9 +335,7 @@ typedef enum {
     TAG_ID3_TAGGINGTIME,                    // tagging time
     TAG_ID3_TERMSOFUSE,                     // terms of use
     TAG_ID3_TIME,                           // time
-    TAG_ID3_TITLE,                          // title
     TAG_ID3_TITLESORTORDER,                 // title sort order
-    TAG_ID3_TRACKNUM,                       // track number
     TAG_ID3_UNIQUEFILEID,                   // unique file identifier
     TAG_ID3_UNSYNCEDLYRICS,                 // unsynchronized lyric
     TAG_ID3_USERTEXT,                       // user defined text information
@@ -313,10 +350,11 @@ typedef enum {
     TAG_ID3_WWWPUBLISHER,                   // official publisher webpage
     TAG_ID3_WWWRADIOPAGE,                   // official internet radio station homepage
     TAG_ID3_WWWUSER,                        // user defined URL link
-    TAG_ID3_YEAR,                           // year
+    TAG_IMAGE_WIDTH,                        // width in pixels
+    TAG_IMAGE_HEIGHT,                       // height in pixels
     TAG_IMAGE_ALBUM,                        // name of an album the image belongs to
-    TAG_IMAGE_CAMERAMAKE,                   // make of camera used to take the image
-    TAG_IMAGE_CAMERAMODEL,                  // model of camera used to take the image
+    TAG_IMAGE_MAKE,                         // make of camera used to take the image
+    TAG_IMAGE_MODEL,                        // model of camera used to take the image
     TAG_IMAGE_COMMENTS,                     // user definable free text
     TAG_IMAGE_COPYRIGHT,                    // embedded copyright message
     TAG_IMAGE_CREATOR,                      // name of the author
@@ -327,7 +365,6 @@ typedef enum {
     TAG_IMAGE_FLASH,                        // set to 1 if flash was fired
     TAG_IMAGE_FNUMBER,                      // diameter of the aperture relative to the effective focal length of the lens.
     TAG_IMAGE_FOCALLENGTH,                  // focal length of lens in mm
-    TAG_IMAGE_HEIGHT,                       // height in pixels
     TAG_IMAGE_ISOSPEED,                     // ISO speed used to acquire the document contents. For example, 100, 200, 400, etc.
     TAG_IMAGE_KEYWORDS,                     // string of keywords
     TAG_IMAGE_METERINGMODE,                 // metering mode used to acquire the image (IE Unknown, Average, CenterWeightedAverage, Spot, MultiSpot, Pattern, Partial)
@@ -335,7 +372,6 @@ typedef enum {
     TAG_IMAGE_SOFTWARE,                     // software used to produce/enhance the image
     TAG_IMAGE_TITLE,                        // title of image
     TAG_IMAGE_WHITEBALANCE,                 // white balance setting of the camera when the picture was taken (auto or manual)
-    TAG_IMAGE_WIDTH,                        // width in pixels
     TAG_IPTC_ACTIONADVISED,                 // type of action that this object provides to a previous object
     TAG_IPTC_ARMID,                         // Abstract Relationship Method (ARM)
     TAG_IPTC_ARMVERSION,                    // version of the Abstract Relationship Method (ARM)
@@ -414,21 +450,141 @@ typedef enum {
     TAG_IPTC_UNO,                           // eternal, globally unique identification for the object, independent of provider and for any media form
     TAG_IPTC_URGENCY,                       // specifies the editorial urgency of content and not necessarily the envelope handling priority
     TAG_IPTC_WRITEREDITOR,                  // name of the person involved in the writing, editing or correcting the object or caption/abstract
-    NUMBER_OF_TAGS
+    TAG_VORBIS_CONTACT,                     // contact information for the creators or distributors of the track
+    TAG_VORBIS_DESCRIPTION,                 // a textual description of the data
+    TAG_VORBIS_LICENSE,                     // license information
+    TAG_VORBIS_LOCATION,                    // location where track was recorded
+    TAG_VORBIS_MAXBITRATE,                  // maximum bitrate in kbps
+    TAG_VORBIS_MINBITRATE,                  // minimum bitrate in kbps
+    TAG_VORBIS_NOMINALBITRATE,              // nominal bitrate in kbps
+    TAG_VORBIS_ORGANIZATION,                // organization producing the track
+    TAG_VORBIS_VENDOR,                      // Vorbis vendor ID
+    TAG_VORBIS_VERSION                      // Vorbis version
 } GnomeCmdTag;
 
 
-GnomeCmdTag gcmd_tags_get_tag_by_long_name(const gchar *tag_name);
-GnomeCmdTag gcmd_tags_get_tag_by_name(const GnomeCmdTagClass tag_class, const gchar *tag_name);
-GnomeCmdTag *gcmd_tags_get_pointer_to_tag(const GnomeCmdTag tag);
-const gchar *gcmd_tags_get_name(GnomeCmdTag tag);
-const gchar *gcmd_tags_get_class_name(GnomeCmdTag tag);
-const gchar *gcmd_tags_get_value(GnomeCmdFile *finfo, GnomeCmdTag tag);
-const gchar *gcmd_tags_get_value_by_long_name(GnomeCmdFile *finfo, const gchar *tag_name);
-const gchar *gcmd_tags_get_value_by_name(GnomeCmdFile *finfo, GnomeCmdTagClass tag_class, const gchar *tag_name);
-const gchar *gcmd_tags_get_title(GnomeCmdTag tag);
-const gchar *gcmd_tags_get_description(GnomeCmdTag tag);
+void gcmd_tags_init();
+void gcmd_tags_shutdown();
+
+GnomeCmdFileMetadata *gcmd_tags_bulk_load(GnomeCmdFile *finfo);
+
+const gchar *gcmd_tags_get_name(const GnomeCmdTag tag);
+const GnomeCmdTagClass gcmd_tags_get_class(const GnomeCmdTag tag);
+const gchar *gcmd_tags_get_class_name(const GnomeCmdTag tag);
+const gchar *gcmd_tags_get_value(GnomeCmdFile *finfo, const GnomeCmdTag tag);
+const gchar *gcmd_tags_get_title(const GnomeCmdTag tag);
+const gchar *gcmd_tags_get_description(const GnomeCmdTag tag);
+
+// gcmd_tags_get_tag_by_name() returns tag for given tag_name (eg. AlbumArtist) in the specified tag_class (here TAG_AUDIO)
+// if tag_class is omitted, tag_name must contain fully qualified tag name (eg. Audio.AlbumArtist)
+
+GnomeCmdTag gcmd_tags_get_tag_by_name(const gchar *tag_name, const GnomeCmdTagClass tag_class=TAG_NONE_CLASS);
+
+// gcmd_tags_get_value_by_name() returns metatag value for given tag_name (eg. AlbumArtist) in the specified tag_class (here TAG_AUDIO)
+// if tag_class is omitted, tag_name must contain fully qualified tag name (eg. Audio.AlbumArtist)
+
+inline const gchar *gcmd_tags_get_value_by_name(GnomeCmdFile *finfo, const gchar *tag_name, const GnomeCmdTagClass tag_class=TAG_NONE_CLASS)
+{
+    g_return_val_if_fail (finfo != NULL, "");
+
+    return gcmd_tags_get_value(finfo, gcmd_tags_get_tag_by_name(tag_name, tag_class));
+}
+
+
+class GnomeCmdFileMetadata
+{
+  public:
+
+    typedef std::map<GnomeCmdTag,std::set<std::string> >   METADATA_COLL;
+
+  private:
+
+    typedef std::map<GnomeCmdTagClass,gboolean>  ACCESSED_COLL;
+
+    ACCESSED_COLL accessed;
+    METADATA_COLL metadata;
+
+    const std::string NODATA;
+
+  public:
+
+    GnomeCmdFileMetadata() {}                                                   // to make g++ 3.4 happy
+
+    gboolean is_accessed (const GnomeCmdTagClass tag_class) const;
+    gboolean is_accessed (const GnomeCmdTag tag) const;
+    void mark_as_accessed (const GnomeCmdTagClass tag_class)        {  accessed[tag_class] = TRUE;  }
+    void mark_as_accessed (const GnomeCmdTag tag);
+
+    void add (const GnomeCmdTag tag, std::string value);
+    void add (const GnomeCmdTag tag, const gchar *value);
+    template <typename T>
+    void add (const GnomeCmdTag tag, const T &value);
+    void addf (const GnomeCmdTag tag, const gchar *fmt, ...);
+
+    gboolean has_tag (const GnomeCmdTag tag);
+
+    const std::string operator[] (const GnomeCmdTag tag);
+
+    METADATA_COLL::const_iterator begin()                           {  return metadata.begin();     }
+    METADATA_COLL::const_iterator end()                             {  return metadata.end();       }
+};
+
+
+inline gboolean GnomeCmdFileMetadata::is_accessed (const GnomeCmdTagClass tag_class) const
+{
+    ACCESSED_COLL::const_iterator elem = accessed.find(tag_class);
+
+    return elem==accessed.end() ? FALSE : elem->second;
+}
+
+
+inline void GnomeCmdFileMetadata::add (const GnomeCmdTag tag, std::string value)
+{
+    if (value.empty())
+        return;
+
+    std::string::size_type end = value.find_last_not_of(" \t\n\r\0",std::string::npos,5);         // remove trailing whitespace from a string
+
+    if (end==std::string::npos)
+        return;
+
+    value.erase(end+1);
+
+    metadata[tag].insert(value);
+}
+
+
+inline void GnomeCmdFileMetadata::add (const GnomeCmdTag tag, const gchar *value)
+{
+    if (value && *value)
+        add(tag, std::string(value));
+}
+
+
+template <typename T>
+inline void GnomeCmdFileMetadata::add (const GnomeCmdTag tag, const T &value)
+{
+   std::ostringstream os;
+
+   os << value;
+   add(tag,os.str());
+}
+
+
+inline gboolean GnomeCmdFileMetadata::has_tag (const GnomeCmdTag tag)
+{
+    METADATA_COLL::const_iterator pos = metadata.find(tag);
+
+    return pos!=metadata.end();
+}
+
+
+inline const std::string GnomeCmdFileMetadata::operator[] (const GnomeCmdTag tag)
+{
+    METADATA_COLL::const_iterator pos = metadata.find(tag);
+
+    return pos==metadata.end() ? NODATA : join(pos->second, ", ");
+}
 
-G_END_DECLS
 
 #endif // __GNOME_CMD_TAGS_H__
